<?php

$mts_options = get_option( MTS_THEME_NAME );

if ( ! function_exists( 'mts_meta' ) ) {
	/**
	 * Display necessary tags in the <head> section.
	 */
	function mts_meta() {
		global $mts_options, $post;
		?>

		<?php if ( ! empty( $mts_options['mts_favicon'] ) && $mts_favicon = wp_get_attachment_url( $mts_options['mts_favicon'] ) ) { ?>
			<link rel="icon" href="<?php echo esc_url( $mts_favicon ); ?>" type="image/x-icon" />
		<?php } elseif ( function_exists( 'has_site_icon' ) && has_site_icon() ) { ?>
			<?php printf( '<link rel="icon" href="%s" sizes="32x32" />', esc_url( get_site_icon_url( 32 ) ) ); ?>
			<?php sprintf( '<link rel="icon" href="%s" sizes="192x192" />', esc_url( get_site_icon_url( 192 ) ) ); ?>
		<?php } ?>

		<?php if ( ! empty( $mts_options['mts_metro_icon'] ) && $mts_metro_icon = wp_get_attachment_url( $mts_options['mts_metro_icon'] ) ) { ?>
			<!-- IE10 Tile.-->
			<meta name="msapplication-TileColor" content="#FFFFFF">
			<meta name="msapplication-TileImage" content="<?php echo esc_url( $mts_metro_icon ); ?>">
		<?php } elseif ( function_exists( 'has_site_icon' ) && has_site_icon( ) ) { ?>
			<?php printf( '<meta name="msapplication-TileImage" content="%s">', esc_url( get_site_icon_url( 270 ) ) ); ?>
		<?php } ?>

		<?php if ( ! empty( $mts_options['mts_touch_icon'] ) && $mts_touch_icon = wp_get_attachment_url( $mts_options['mts_touch_icon'] ) ) { ?>
			<!--iOS/android/handheld specific -->
			<link rel="apple-touch-icon-precomposed" href="<?php echo esc_url( $mts_touch_icon ); ?>" />
		<?php } elseif ( function_exists( 'has_site_icon' ) && has_site_icon() ) { ?>
			<?php printf( '<link rel="apple-touch-icon-precomposed" href="%s">', esc_url( get_site_icon_url( 180 ) ) ); ?>
		<?php } ?>

		<?php if ( ! empty( $mts_options['mts_responsive'] ) ) { ?>
			<meta name="viewport" content="width=device-width, initial-scale=1">
			<meta name="apple-mobile-web-app-capable" content="yes">
			<meta name="apple-mobile-web-app-status-bar-style" content="black">
		<?php } ?>

		<?php if( $mts_options['mts_prefetching'] == '1' ) { ?>
			<?php if ( is_front_page() ) { ?>
				<?php $my_query = new WP_Query('posts_per_page=1'); while ($my_query->have_posts()) : $my_query->the_post(); ?>
				<link rel="prefetch" href="<?php the_permalink(); ?>">
				<link rel="prerender" href="<?php the_permalink(); ?>">
				<?php endwhile; wp_reset_postdata(); ?>
			<?php } elseif ( is_singular() ) { ?>
				<link rel="prefetch" href="<?php echo esc_url( home_url() ); ?>">
				<link rel="prerender" href="<?php echo esc_url( home_url() ); ?>">
			<?php } ?>
		<?php } ?>

		<meta itemprop="name" content="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" />

		<?php if ( is_singular() ) { ?>
			<?php $user_info = get_userdata($post->post_author); ?>
			<?php if ( $user_info && ! empty( $user_info->first_name ) && ! empty( $user_info->last_name ) ) : ?>
				<meta itemprop="creator accountablePerson" content="<?php echo $user_info->first_name.' '.$user_info->last_name; ?>" />
			<?php endif; ?>
		<?php } ?>
<?php
	}
}

if ( ! function_exists( 'mts_head' ) ) {
	/**
	 * Display header code from Theme Options.
	 */
	function mts_head() {
		global $mts_options;
		echo $mts_options['mts_header_code'];
	}
}
add_action( 'wp_head', 'mts_head' );

if ( ! function_exists( 'mts_copyrights_credit' ) ) {
	/**
	 * Display the footer copyright.
	 */
	function mts_copyrights_credit() {
		global $mts_options;
		?>
		<!--start copyrights-->
		<div class="row" id="copyright-note">
			<?php
			$copyright_text = '<a href=" ' . esc_url( trailingslashit( home_url() ) ). '" title=" ' . get_bloginfo('description') . '">' . get_bloginfo('name') . '</a> Copyright &copy; ' . date("Y");
			?>
			<span><?php echo apply_filters( 'mts_copyright_content', $copyright_text ); ?></span>
			<span class="to-top"><?php echo $mts_options['mts_copyrights']; ?></span>
		</div>
		<!--end copyrights-->
		<?php
	}
}

if ( ! function_exists( 'mts_footer' ) ) {
	/**
	 * Display the analytics code in the footer.
	 */
	function mts_footer() {
		global $mts_options;
		if ( $mts_options['mts_analytics_code'] != '' ) {
			// start footer code.
			echo $mts_options['mts_analytics_code'];
			// end footer code.
		}
	}
}

// Last item in the breadcrumbs
if ( ! function_exists( 'get_itemprop_3' ) ) {
	function get_itemprop_3( $title = '', $position = '2' ) {
		echo '<div itemprop="itemListElement" itemscope itemtype="https://schema.org/ListItem">';
		echo '<span itemprop="name">' . $title . '</span>';
		echo '<meta itemprop="position" content="' . $position . '" />';
		echo '</div>';
	}
}
if ( ! function_exists( 'mts_the_breadcrumb' ) ) {
	/**
	 * Display the breadcrumbs.
	 */
	function mts_the_breadcrumb() {
		if ( is_front_page() ) {
				return;
		}
		if ( function_exists( 'rank_math_the_breadcrumbs' ) && RankMath\Helper::get_settings( 'general.breadcrumbs' ) ) {
			rank_math_the_breadcrumbs();
			return;
		}
		echo '<div class="breadcrumb" itemscope itemtype="https://schema.org/BreadcrumbList">';
		echo '<div itemprop="itemListElement" itemscope
	      itemtype="https://schema.org/ListItem" class="root"><a href="';
		echo esc_url( home_url() );
		echo '" itemprop="item"><span itemprop="name">' . esc_html__( 'Home', 'dropshipping' );
		echo '</span><meta itemprop="position" content="1" /></a></div>';
		if ( is_single() ) {
			$categories = get_the_category();
			if ( $categories ) {
				$level         = 0;
				$hierarchy_arr = [];
				foreach ( $categories as $cat ) {
					$anc       = get_ancestors( $cat->term_id, 'category' );
					$count_anc = count( $anc );
					if ( 0 < $count_anc && $level < $count_anc ) {
						$level         = $count_anc;
						$hierarchy_arr = array_reverse( $anc );
						array_push( $hierarchy_arr, $cat->term_id );
					}
				}
				if ( empty( $hierarchy_arr ) ) {
					$category = $categories[0];
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>';
				} else {
					foreach ( $hierarchy_arr as $cat_id ) {
						$category = get_term_by( 'id', $cat_id, 'category' );
						echo '<div itemprop="itemListElement" itemscope
					      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>';
					}
				}
				get_itemprop_3( get_the_title(), '3' );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_page() ) {
			$parent_id = wp_get_post_parent_id( get_the_ID() );
			if ( $parent_id ) {
				$breadcrumbs = [];
				while ( $parent_id ) {
					$page          = get_page( $parent_id );
					$breadcrumbs[] = '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_permalink( $page->ID ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( get_the_title( $page->ID ) ) . '</span><meta itemprop="position" content="2" /></a></div>';
					$parent_id = $page->post_parent;
				}
				$breadcrumbs = array_reverse( $breadcrumbs );
				foreach ( $breadcrumbs as $crumb ) { echo $crumb; }
				get_itemprop_3( get_the_title(), 3 );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_category() ) {
			global $wp_query;
			$cat_obj       = $wp_query->get_queried_object();
			$this_cat_id   = $cat_obj->term_id;
			$hierarchy_arr = get_ancestors( $this_cat_id, 'category' );
			if ( $hierarchy_arr ) {
				$hierarchy_arr = array_reverse( $hierarchy_arr );
				foreach ( $hierarchy_arr as $cat_id ) {
					$category = get_term_by( 'id', $cat_id, 'category' );
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>';
				}
			}
			get_itemprop_3( single_cat_title( '', false ) );
		} elseif ( is_author() ) {
			if ( get_query_var( 'author_name' ) ) :
				$curauth = get_user_by( 'slug', get_query_var( 'author_name' ) );
			else :
				$curauth = get_userdata( get_query_var( 'author' ) );
			endif;
			get_itemprop_3( esc_html( $curauth->nickname ) );
		} elseif ( is_search() ) {
			get_itemprop_3( get_search_query() );
		} elseif ( is_tag() ) {
			get_itemprop_3( single_tag_title( '', false ) );
		}
		echo '</div>';
	}
}

/**
 * Display schema-compliant the_category()
 *
 * @param string $separator
 */
function mts_the_category( $separator = ', ' ) {
	$categories = get_the_category();
	$count = count( $categories );
	foreach ( $categories as $i => $category ) {
		echo '<a href="' . esc_url( get_category_link( $category->term_id ) ) . '" title="' . sprintf( __( "View all posts in %s", 'dropshipping' ), esc_attr( $category->name ) ) . '">' . esc_html( $category->name ).'</a>';
		if ( $i < $count - 1 )
			echo $separator;
	}
}

/**
 * Display schema-compliant the_tags()
 *
 * @param string $before
 * @param string $sep
 * @param string $after
 */
function mts_the_tags( $before = '', $sep = ' ', $after = '</div>' ) {
	if ( empty( $before ) ) {
		$before = '<div class="tags border-bottom">' . esc_html__( 'Tags: ', 'dropshipping' );
	}

	$tags = get_the_tags();
	if ( empty( $tags ) || is_wp_error( $tags ) ) {
		return;
	}
	$tag_links = [];
	foreach ( $tags as $tag ) {
		$link        = get_tag_link($tag->term_id);
		$tag_links[] = '<a href="' . esc_url( $link ) . '" rel="tag">' . $tag->name . '</a>';
	}
	echo $before . join( $sep, $tag_links ). $after;
}

if ( ! function_exists( 'mts_pagination' ) ) {
	/**
	 * Display the pagination.
	 *
	 * @param string $pages
	 * @param int $range
	 */
	function mts_pagination( $pages = '', $range = 3, $pagenavigation_type = 'mts_pagenavigation_type' ) {
		$mts_options = get_option( MTS_THEME_NAME );
		if ( isset( $mts_options[ $pagenavigation_type ] ) && $mts_options[ $pagenavigation_type ] == '1' ) { // numeric pagination.
			the_posts_pagination(
				[
					'mid_size'  => 3,
					'prev_text' => '<i class="fa fa-angle-left"></i> ' . esc_html__( 'Previous', 'dropshipping' ),
					'next_text' => esc_html__( 'Next', 'dropshipping' ) . ' <i class="fa fa-angle-right"></i>',
				]
			);
		} else { // traditional or ajax pagination.
			?>
			<div class="pagination pagination-previous-next">
			<ul>
				<li class="nav-previous"><?php next_posts_link( '<i class="fa fa-angle-left"></i> ' . esc_html__( 'Previous', 'dropshipping' ) ); ?></li>
				<li class="nav-next"><?php previous_posts_link( esc_html__( 'Next', 'dropshipping' ) . ' <i class="fa fa-angle-right"></i>' ); ?></li>
			</ul>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'mts_cart' ) ) {
	/**
	 * Display Header cart buttons.
	 */
	function mts_cart() {

		global $mts_options, $woocommerce;

		$cart_contents_count = WC()->cart->get_cart_contents_count();
		?>

		<div class="mts-header-button-wrap">
			<a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="mts-header-cart-button cart-contents">
				<span class="mts-cart-icon"><i class="fa fa-shopping-cart"></i></span><span class="count"><?php echo esc_attr( $cart_contents_count ); ?></span><?php echo WC()->cart->get_cart_total(); ?>
			</a>
			<div class="mts-cart-content">
				<h3 class="mts-cart-heading"><?php esc_html_e( 'Shopping Cart', 'dropshipping' ); ?></h3>
				<?php
				if ( $cart_contents_count > '0' ) {
					?>
					<div class="mts-cart-content-body">
						<?php
						foreach ( WC()->cart->cart_contents as $cart_item_key => $cart_item ) {

							$cart_item_data = $cart_item['data'];

							$_product = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );

							if ( $cart_item_data->exists() && $cart_item['quantity'] > 0 ) {
								$product_title     = $cart_item_data->get_title();
								$product_permalink = get_permalink( $cart_item['product_id'] );
								?>
								<div class="mts-cart-product clearfix">
									<a class="mts-cart-product-image" href="<?php echo esc_url( $product_permalink ); ?>"><?php echo $cart_item_data->get_image(); ?></a>
									<div class="mts-cart-product-data">
										<h4 class="mts-cart-product-title">
											<a href="<?php echo esc_url( $product_permalink ); ?>"><?php echo esc_html( $product_title ); ?></a>
										</h4>
										<div class="mts-quantity"><?php echo $cart_item['quantity']; esc_html_e(' X '); echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); ?></div>
									</div>
									<div class="mts-product-data-right">
										<?php echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf( '<a href="%s" class="remove" title="%s">&times;</a>', esc_url( wc_get_cart_remove_url( $cart_item_key ) ), __( 'Remove this item', 'dropshipping' ) ), $cart_item_key ); ?>
										<div class="blank-data">&nbsp;</div><!--don't remove this div-->
									</div>
								</div>
							<?php }
						} ?>
					</div>
					<div class="mts-cart-content-footer clearfix">
						<div class="mts-cart-total">
							<strong><?php esc_html_e( 'Subtotal:', 'dropshipping' ); ?></strong>
							<span class="mts-cart-amount"><?php echo WC()->cart->get_cart_total(); ?></span>
						</div>
						<a href="<?php echo esc_url( esc_url( wc_get_cart_url() ) ); ?>" class="button mts-cart-button"><?php esc_html_e( 'View Cart', 'dropshipping' ); ?></a>
						<a href="<?php echo esc_url( wc_get_checkout_url() ); ?>" class="button mts-cart-button mts-checkout-button"><?php esc_html_e( 'Checkout', 'dropshipping' ); ?></a>
					</div>
				<?php } else { ?>
					<div class="mts-cart-content-footer clearfix">
						<div class="mts-cart-total">
							<strong><?php esc_html_e( 'Subtotal:', 'dropshipping' ); ?></strong>
							<span class="mts-cart-amount"><?php echo WC()->cart->get_cart_total(); ?></span>
						</div>
						<a href="<?php echo esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ); ?>" class="button mts-cart-button"><?php _e( 'Return to Shop', 'dropshipping' ); ?></a>
					</div>
				<?php } ?>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'mts_wishlist_link' ) ) {
	/**
	 * Header Wish List Link.
	 */
	function mts_wishlist_link() {
		global $mts_options;
		if ( mts_is_wc_active() ) {
			?>
			<div class="mts-wishlist">
				<a href="<?php echo esc_url( mts_get_wishlist_page_url() ); ?>" class="mts-wishlist-link">
					<span class="mts-wishlist-icon"><i class="fa fa-heart-o"></i></span><span class="mts-wishlist-link-count count"><?php mts_wishlist_count(); ?></span>
				</a>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'mts_wishlist_button' ) ) {
	/**
	 * WooCommerce Archive Wishlist Button.
	 */
	function mts_wishlist_button() {

		global $mts_options;
		if ( isset( $mts_options['mts_wishlist'] ) && ! empty( $mts_options['mts_wishlist'] ) ) {
			global $product;

			$url          = mts_get_wishlist_page_url();
			$product_type = $product->get_type();
			$exists       = mts_product_in_wishlist( $product->get_id() );

			$added_class = $exists ? ' added' : '';

			$html = '<a href="' . $url . '" data-product-id="' . $product->get_id() . '" data-product-type="' . $product_type . '" class="mts-add-to-wishlist button' . $added_class . '"><i class="fa fa-heart-o"></i><span></span></a>';

			return $html;
		}
	}
}

if ( ! function_exists( 'mts_single_wishlist_button' ) ) {
	/**
	 * WooCommerce Single product wishlist,
	 */
	function mts_single_wishlist_button() {

		global $mts_options;
		if ( isset( $mts_options['mts_wishlist'] ) && ! empty( $mts_options['mts_wishlist'] ) ) {

			global $product;

			$url          = mts_get_wishlist_page_url();
			$product_type = $product->get_type();
			$exists       = mts_product_in_wishlist( $product->get_id() );

			$button_label = ( is_product() && 'woocommerce_after_add_to_cart_button' === current_filter() )  ? esc_html__( 'Add To Wishlist', 'dropshipping' ) : '';
			$added_class  = $exists ? ' added' : '';

			$html = '<a href="' . $url . '" data-product-id="' . $product->get_id() . '" data-product-type="' . $product_type . '" class="mts-add-to-wishlist button' . $added_class . '"><i class="fa fa-heart-o"></i><span>' . $button_label . '</span></a>';

			return $html;
		}
	}
}

if ( ! function_exists( 'mts_related_posts' ) ) {
	/**
	 * Display the related posts.
	 */
	function mts_related_posts() {
		$post_id     = get_the_ID();
		$mts_options = get_option( MTS_THEME_NAME );
		?>
			<!-- Start Related Posts -->
			<?php
			$empty_taxonomy = false;
			if ( empty( $mts_options['mts_related_posts_taxonomy'] ) || $mts_options['mts_related_posts_taxonomy'] == 'tags' ) {
				// Related posts based on tags.
				$tags = get_the_tags( $post_id );
				if ( empty( $tags ) ) {
					$empty_taxonomy = true;
				} else {
					$tag_ids = [];
					foreach( $tags as $individual_tag ) {
						$tag_ids[] = $individual_tag->term_id;
					}
					$args = [
						'tag__in'             => $tag_ids,
						'post__not_in'        => [ $post_id ],
						'posts_per_page'      => isset( $mts_options['mts_related_postsnum'] ) ? $mts_options['mts_related_postsnum'] : 3,
						'ignore_sticky_posts' => 1,
						'orderby'             => 'rand',
					];
				}
			} else {
				// Related posts based on categories.
				$categories = get_the_category( $post_id );
				if ( empty( $categories ) ) {
					$empty_taxonomy = true;
				} else {
					$category_ids = [];
					foreach( $categories as $individual_category )
						$category_ids[] = $individual_category->term_id;
					$args = [
						'category__in'        => $category_ids,
						'post__not_in'        => [ $post_id ],
						'posts_per_page'      => $mts_options['mts_related_postsnum'],
						'ignore_sticky_posts' => 1,
						'orderby'             => 'rand',
					];
				}
			}
			if ( ! $empty_taxonomy ) {
				$my_query = new WP_Query( apply_filters( 'mts_related_posts_query_args', $args, isset( $mts_options['mts_related_posts_taxonomy'] ) ) );
				if ( $my_query->have_posts() ) {
					echo '<div class="related-posts">';
					echo '<h4>' . esc_html_e( 'Related Posts', 'dropshipping' ) . '</h4>';
					echo '<div class="related-post-slider-container clearfix loading">';
					echo '<div id="related-post-slider" class="related-post-slider">';
					while ( $my_query->have_posts() ) {
						$my_query->the_post();
						?>
						<div class="related-post-slider-item">
							<article class="latestPost excerpt">
								<div class="post-inner">
									<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_html( get_the_title() ); ?>" class="post-image post-image-left">
										<?php
										echo '<div class="featured-thumbnail">';
										$attr = [
											'title' => esc_attr( get_the_title() ),
											'alt'   => esc_attr( get_the_title() ),
										];
										the_post_thumbnail( 'dropshipping-related', $attr );
										echo '</div>';
										if ( function_exists( 'wp_review_show_total' ) ) {
											wp_review_show_total( true, 'latestPost-review-wrapper' );
										}
										?>
									</a>
									<?php get_post_date_meta( 'home' ); ?>
									<div class="post-wrapper">
										<?php get_post_category_meta( 'home' ); ?>
										<header>
											<h2 class="title front-view-title"><a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_html( get_the_title() ); ?>"><?php the_title(); ?></a></h2>
										</header>
										<?php get_blog_post_meta( 'home' ); ?>
										<div class="front-view-content">
											<?php echo mts_excerpt(25); ?>
										</div>
										<?php mts_readmore(); ?>
									</div>
								</div>
							</article>
						</div>
						<?php
					}
					echo '</div></div></div>';
				}
			}
			wp_reset_postdata();
			?>
			<!-- .related-posts -->
		<?php //}
	}
}

if ( ! function_exists( 'mts_social_buttons' ) ) {
	/**
	 * Display the social sharing buttons.
	 */
	function mts_social_buttons() {
		$mts_options = get_option( MTS_THEME_NAME );
		$buttons     = [];

		if ( isset( $mts_options['mts_social_buttons'] ) && is_array( $mts_options['mts_social_buttons'] ) && array_key_exists( 'enabled', $mts_options['mts_social_buttons'] ) ) {
			$buttons = $mts_options['mts_social_buttons']['enabled'];
		}

		if ( ! empty( $buttons ) ) {
			?>
			<!-- Start Share Buttons -->
			<div class="shareit">
				<?php
				foreach ( $buttons as $key => $button ) {
					mts_social_button( $key );
				}
				?>
			</div>
			<!-- end Share Buttons -->
			<?php
		}
	}
}

if ( ! function_exists( 'mts_product_social_buttons' ) ) {
	/**
	 * Display the social sharing buttons on products.
	 */
	function mts_product_social_buttons() {
		$mts_options = get_option( MTS_THEME_NAME );
		$buttons     = [];

		if ( isset( $mts_options['mts_product_social_buttons'] ) && is_array( $mts_options['mts_product_social_buttons'] ) && array_key_exists( 'enabled', $mts_options['mts_product_social_buttons'] ) ) {
			$buttons = $mts_options['mts_product_social_buttons']['enabled'];
		}

		if ( ! empty( $buttons ) ) {
			?>
			<!-- Start Share Buttons -->
			<div class="shareit-product">
				<span><?php esc_html_e( 'Share:', 'dropshipping' ); ?></span>
				<?php
				foreach ( $buttons as $key => $button ) {
					mts_social_button( $key );
				}
				?>
			</div>
			<!-- end Share Buttons -->
			<?php
		}
	}
}

if ( ! function_exists( 'mts_social_button' ) ) {
	/**
	 * Display network-independent sharing buttons.
	 *
	 * @param $button social button layout.
	 */
	function mts_social_button( $button ) {

		$mts_options = get_option( MTS_THEME_NAME );
		global $post;
		$text = esc_html( get_the_title() );
		$link = rawurlencode( get_permalink() );
		if ( is_single() ) {
			$img_url = '';
			$img     = '';
			if ( has_post_thumbnail( $post->ID ) ) {
				$img     = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'media-featuredfull' );
				$img_url = $img[0];
			}
		}
		switch ( $button ) {
			case 'facebookshare':
				?>
				<!-- Facebook -->
				<div class="share-item facebooksharebtn">
					<a target="_blank" href="//www.facebook.com/share.php?m2w&s=100&p[url]=<?php echo $link; ?>&p[images][0]=<?php echo urlencode( $img_url ); ?>&p[title]=<?php echo $text; ?>&u=<?php echo $link; ?>&t=<?php echo $text; ?>" class="single-social" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-facebook-official"></i></a>
				</div>
				<?php
				break;
			case 'twitter':
				?>
				<!-- Twitter -->
				<div class="share-item twitterbtn">
					<?php
					$via = '';
					if ( $mts_options['mts_twitter_username'] ) {
						$via = '&via=' . $mts_options['mts_twitter_username'];
					}
					?>
					<a target="_blank" href="https://twitter.com/intent/tweet?original_referer=<?php echo $link; ?>&text=<?php echo $text; ?>&url=<?php echo $link; ?><?php echo $via; ?>" class="single-social" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-twitter"></i></a>
				</div>
				<?php
				break;

			case 'pinterest':
				global $post;
				?>
				<!-- Pinterest -->
				<?php $pinterestimage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' ); ?>
				<div class="share-item pinbtn">
					<a target="_blank" href="http://pinterest.com/pin/create/button/?url=<?php echo $link; ?>&media=<?php echo $pinterestimage[0]; ?>&description=<?php the_title(); ?>" class="single-social" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-pinterest"></i></a>
				</div>
				<?php
				break;
			case 'linkedin':
				?>
				<!--Linkedin -->
				<div class="share-item linkedinbtn">
					<a target="_blank" href="//www.linkedin.com/shareArticle?mini=true&url=<?php echo $link; ?>&title=<?php echo $text; ?>&source=<?php echo 'url'; ?>" class="single-social" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-linkedin"></i></a>
				</div>
				<?php
				break;
			case 'reddit':
				?>
				<!-- Reddit -->
				<div class="share-item reddit">
					<a target="_blank" href="//www.reddit.com/submit" class="single-social" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-reddit-alien"></i></a>
				</div>
				<?php
				break;
			case 'whatsapp':
				?>
				<!--WhatsApp -->
				<div class="share-item whatsapp">
					<a target="_blank" href="https://wa.me/?text=<?php echo $text . ' ' . $link; ?>" class="single-social" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="fa fa-whatsapp"></i></a>
				</div>
				<?php
				break;
			case 'telegram':
				?>
				<!-- Telegram -->
				<div class="share-item telegram">
					<a href="javascript:window.open('https://telegram.me/share/url?url='+encodeURIComponent(window.location.href), '_blank')" class="single-social"><i class="fa fa-paper-plane"></i></a>
				</div>
				<?php
				break;
			case 'tumblr':
				?>
				<!-- Tumblr -->
				<div class="share-item tumblr">
					<a target="_blank" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo $link; ?>&title=<?php echo $text; ?>" class="single-social"><i class="fa fa-tumblr"></i></a>
				</div>
				<?php
				break;
			case 'pocket':
				?>
				<!-- Pocket -->
				<div class="share-item pocket">
					<a target="_blank" href="https://getpocket.com/save?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="single-social"><i class="fa fa-get-pocket"></i></a>
				</div>
				<?php
				break;
			case 'buffer':
				?>
				<!-- Buffer -->
				<div class="share-item buffer">
					<a target="_blank" href="https://bufferapp.com/add?url=<?php echo $link; ?>&amp;text=<?php echo $text; ?>" class="single-social"><svg height="18px" id="Layer_1" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><g><path d="M70.7,164.5l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7c8.9-4.3,8.9-11.3,0-15.6L272.1,67.2    c-4.4-2.1-10.3-3.2-16.1-3.2s-11.7,1.1-16.1,3.2L70.7,148.9C61.8,153.2,61.8,160.2,70.7,164.5z"/><path d="M441.3,248.2c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1s-124.8,60.2-124.8,60.2c-4.5,2.1-10.3,3.2-16.1,3.2    s-11.7-1.1-16.1-3.2c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6    l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,259.5,450.2,252.5,441.3,248.2z"/></g><path d="M441.3,347.5c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1S272.1,391,272.1,391c-4.5,2.1-10.3,3.2-16.1,3.2s-11.7-1.1-16.1-3.2   c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6l169.2,81.7   c4.4,2.2,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,358.8,450.2,351.8,441.3,347.5z"/></g></svg></a>
				</div>
				<?php
				break;
			case 'vkontakte':
				?>
				<!-- Vkontakte -->
				<div class="share-item vkontakte">
					<a target="_blank" href="http://vk.com/share.php?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="single-social"><i class="fa fa-vk"></i></a>
				</div>
				<?php
				break;
			case 'mix':
				?>
				<!-- Mix -->
				<div class="share-item mix">
					<a target="_blank" href="https://mix.com/add?url=<?php echo $link; ?>" class="single-social"><svg height="18px" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="comp_x5F_217-mix"><g><path d="M26.001,54.871v358.246c0,57.705,90.357,59.656,90.357,0V168.124c8.11-54.316,90.357-51.749,90.357,6.675v179.994    c0,59.453,98.57,59.556,98.57,0V235.584c5.44-56.166,90.357-53.906,90.357,4.415v24.44c0,61.503,90.355,58.114,90.355,0V54.871    H26.001z"/></g></g><g id="Layer_1"/></svg></a>
				</div>
				<?php
				break;
		}
	}
}

if ( ! function_exists( 'mts_article_class' ) ) {
	/**
	 * Custom `<article>` class name.
	 */
	function mts_article_class() {
		$mts_options = get_option( MTS_THEME_NAME );
		$class       = 'article';

		// sidebar or full width
		if ( mts_custom_sidebar() == 'mts_nosidebar' ) {
			$class = 'ss-full-width';
		}

		echo $class;
	}
}

if ( ! function_exists( 'mts_single_page_class' ) ) {
	/**
	 * Custom `#page` class name.
	 */
	function mts_single_page_class() {
		$class = '';

		if ( is_single() || is_page() ) {

			$class = 'single';

			$header_animation = mts_get_post_header_effect();
			if ( ! empty( $header_animation )) $class .= ' '.$header_animation;
		}

		echo $class;
	}
}

if ( ! function_exists( 'get_post_category_meta' ) ) {
	/**
	 * Category Meta.
	 *
	 * @param string $content pages on which category will be shown.
	 */
	function get_post_category_meta( $content = 'single' ) {

		global $mts_options;

		if ( '1' == isset( $mts_options['mts_' . $content . '_meta_info_enable']['category'] ) ) { //phpcs:ignore
			?>
			<div class="thecategory"><div class="thecat-inner"><?php mts_the_category(', ') ?></div></div>
			<?php
		}
	}
}

if ( ! function_exists( 'get_post_date_meta' ) ) {
	/**
	 * Dates Meta.
	 *
	 * @param string $content pages on which date will be shown.
	 */
	function get_post_date_meta( $content = 'single' ) {

		global $mts_options;

		if ( '1' == isset( $mts_options['mts_' . $content . '_meta_info_enable']['time'] ) ) { //phpcs:ignore
			if ( isset( $mts_options['mts_date_layout'] ) && $mts_options['mts_date_layout'] == 'datebig' ) {
				?>
				<span class="thetime date updated">
					<div class="day"><?php echo get_the_time('d'); ?></div>
					<span class="month"><?php echo get_the_time('M'); ?></span>
				</span>
				<?php
			} else {
				?>
				<span class="thetime date updated thedate"><span><?php the_time( get_option( 'date_format' ) ); ?></span></span>
				<?php
			}
		}
	}
}

if ( ! function_exists( 'get_blog_post_meta' ) ) {
	/**
	 * Author & Comments Meta.
	 *
	 * @param string $content pages on which Author & Comment Meta will be shown.
	 */
	function get_blog_post_meta( $content = 'single' ) {

		global $mts_options;

		?>

		<div class="post-info">
			<?php
			if ( isset( $mts_options['mts_' . $content . '_meta_info_enable']['author'] ) == '1' ) { //phpcs:ignore
				?>
				<div class="theauthor"><?php esc_html_e( 'Posted by', 'dropshipping' ); ?><?php echo get_avatar( get_the_author_meta('email'), 18 ); ?><?php the_author_posts_link(); ?></div>
				<?php
			}
			if ( isset( $mts_options['mts_' . $content . '_meta_info_enable']['comment'] ) == '1' ) { //phpcs:ignore
				?>
				<div class="thecomment"><a href="<?php echo esc_url( get_comments_link() ); ?>" itemprop="interactionCount"><span class="comment-number"><?php comments_number( '0', '1', '%' );?></span></a></div>
				<?php
			}
			?>
		</div>

		<?php
	}
}

if ( ! function_exists( 'mts_credit_cards' ) ) {
	/**
	 * Credit Cards
	 */
	function mts_credit_cards() {

		global $mts_options;

		$payment_method_icons = $mts_options['mts_accepted_payment_method_icons'];

		if ( empty( $payment_method_icons ) ) {
			return;
		}
		?>
		<div class="mts-payment-method">
			<ul class="card-list">
			<?php
			foreach ( $payment_method_icons as $icon ) {

				$icon_title   = $icon['mts_accepted_payment_method_title'];
				$card_icon    = $icon['mts_accepted_payment_method_icon'];
				$custom_image = $icon['mts_accepted_payment_method_image'];

				if ( $custom_image ) {
					sprintf(
						'<li><img src="%1$s title="%2$s" alt="%2$s"/></li>',
						$custom_image,
						$icon_title
					);
				} else {
					?>
					<li><i class="fa fa-<?php echo $card_icon; ?>"></i></li>
					<?php
				}
			}
			?>
			</ul>
		</div>
		<?php
	}
}

if ( ! function_exists( 'mts_archive_post' ) ) {
	/**
	 * Display a post of specific layout.
	 *
	 * @param string $layout blog layouts.
	 */
	function mts_archive_post( $layout = '' ) {

		$mts_options = get_option( MTS_THEME_NAME );

		$blog_layout = isset( $mts_options['mts_blog_posts_layout'] ) ? $mts_options['mts_blog_posts_layout'] : 'default';

		if ( 'grid-1' === $blog_layout ) {
			$featuredthumb = 'dropshipping-featuredgrid1';
		}
		if ( 'grid-2' === $blog_layout ) {
			$featuredthumb = 'dropshipping-featuredgrid2';
		}
		if ( 'default' === $blog_layout ) {
			$featuredthumb = 'dropshipping-featured';
		}
		?>

		<div class="post-inner">
			<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_html( get_the_title() ); ?>" class="post-image post-image-left">
				<?php
				echo '<div class="featured-thumbnail">';
				$attr = [
					'title' => esc_attr( get_the_title() ),
					'alt'   => esc_attr( get_the_title() ),
				];
				the_post_thumbnail( $featuredthumb, $attr );
				echo '</div>';
				if ( function_exists( 'wp_review_show_total' ) ) {
					wp_review_show_total( true, 'latestPost-review-wrapper' );
				}
				?>
			</a>
			<?php get_post_date_meta( 'home' ); ?>
			<div class="post-wrapper">
				<?php get_post_category_meta( 'home' ); ?>
				<header>
					<h2 class="title front-view-title"><a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_html( get_the_title() ); ?>"><?php the_title(); ?></a></h2>
				</header>
				<?php get_blog_post_meta( 'home' ); ?>
				<div class="front-view-content">
					<?php echo mts_excerpt(25); ?>
				</div>
				<?php mts_readmore(); ?>
			</div>
		</div>
		<?php
	}
}

function mts_theme_action( $action = null ) {
	update_option( 'mts__thl', '1' );
	update_option( 'mts__pl', '1' );
}

function mts_theme_activation( $oldtheme_name = null, $oldtheme = null ) {
	// Check for Connect plugin version > 1.4.
	if ( class_exists( 'mts_connection' ) && defined( 'MTS_CONNECT_ACTIVE' ) && MTS_CONNECT_ACTIVE ) {
			return;
	}
	$plugin_path = 'mythemeshop-connect/mythemeshop-connect.php';

	// Check if plugin exists.
	if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}
	$plugins = get_plugins();
	if ( ! array_key_exists( $plugin_path, $plugins ) ) {
		// auto-install it.
		include_once ABSPATH . 'wp-admin/includes/misc.php';
		include_once ABSPATH . 'wp-admin/includes/file.php';
		include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
		include_once ABSPATH . 'wp-admin/includes/plugin-install.php';
		$skin        = new Automatic_Upgrader_Skin();
		$upgrader    = new Plugin_Upgrader( $skin );
		$plugin_file = 'https://www.mythemeshop.com/mythemeshop-connect.zip';
		$result      = $upgrader->install( $plugin_file );
		// If install fails then revert to previous theme.
		if ( is_null( $result ) || is_wp_error( $result ) || is_wp_error( $skin->result ) ) {
			switch_theme( $oldtheme->stylesheet );
			return false;
		}
	} else {
		// Plugin is already installed, check version.
		$ver = isset( $plugins[ $plugin_path ]['Version'] ) ? $plugins[ $plugin_path ]['Version'] : '1.0';
		if ( version_compare( $ver, '2.0.5' ) === -1 ) {
			include_once ABSPATH . 'wp-admin/includes/misc.php';
			include_once ABSPATH . 'wp-admin/includes/file.php';
			include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
			include_once ABSPATH . 'wp-admin/includes/plugin-install.php';
			$skin     = new Automatic_Upgrader_Skin();
			$upgrader = new Plugin_Upgrader( $skin );

			add_filter( 'pre_site_transient_update_plugins', 'mts_inject_connect_repo', 10, 2 );
			$result = $upgrader->upgrade( $plugin_path );
			remove_filter( 'pre_site_transient_update_plugins', 'mts_inject_connect_repo' );

			// If update fails then revert to previous theme.
			if ( is_null( $result ) || is_wp_error( $result ) || is_wp_error( $skin->result ) ) {
				switch_theme( $oldtheme->stylesheet );
				return false;
			}
		}
	}
	$activate = activate_plugin( $plugin_path );
}

function mts_inject_connect_repo( $pre, $transient ) {
	$plugin_file = 'https://www.mythemeshop.com/mythemeshop-connect.zip';

	$return           = new stdClass();
	$return->response = [];
	$return->response['mythemeshop-connect/mythemeshop-connect.php']          = new stdClass();
	$return->response['mythemeshop-connect/mythemeshop-connect.php']->package = $plugin_file;

	return $return;
}

add_action( 'wp_loaded', 'mts_maybe_set_constants' );
function mts_maybe_set_constants() {
	if ( ! defined( 'MTS_THEME_S' ) ) {
		mts_set_theme_constants();
	}
}

add_action( 'init', 'mts_nhp_sections_override', -11 );
function mts_nhp_sections_override() {
	define( 'MTS_THEME_INIT', 1 );
	if ( class_exists( 'mts_connection' ) && defined( 'MTS_CONNECT_ACTIVE' ) && MTS_CONNECT_ACTIVE ) {
		return;
	}
	if ( ! get_option( MTS_THEME_NAME, false ) ) {
		return;
	}
	add_filter( 'nhp-opts-sections', '__return_empty_array' );
	add_filter( 'nhp-opts-sections', 'mts_nhp_section_placeholder' );
	add_filter( 'nhp-opts-args', 'mts_nhp_opts_override' );
	add_filter( 'nhp-opts-extra-tabs', '__return_empty_array', 11, 1 );
}

function mts_nhp_section_placeholder( $sections ) {
	$sections[] = [
		'icon'   => 'fa fa-cogs',
		'title'  => __( 'Not Connected', 'schema' ),
		'desc'   => '<p class="description">' . __( 'You will find all the theme options here after connecting with your MyThemeShop account.', 'schema' ) . '</p>',
		'fields' => [],
	];
	return $sections;
}

function mts_nhp_opts_override( $opts ) {
	$opts['show_import_export']    = false;
	$opts['show_typography']       = false;
	$opts['show_translate']        = false;
	$opts['show_child_theme_opts'] = false;
	$opts['last_tab']              = 0;

	return $opts;
}
