<?php
/**
 * Displays Theme Options Panel.
 *
 * @package Dropshipping
 */

defined( 'ABSPATH' ) or die;

/*
 *
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
 */
require_once( dirname( __FILE__ ) . '/options/options.php' );

/*
 *
 * Add support tab
 *
 */
if ( ! defined( 'MTS_THEME_WHITE_LABEL' ) || ! MTS_THEME_WHITE_LABEL ) {
	require_once( dirname( __FILE__ ) . '/options/support.php' );
	$mts_options_tab_support = MTS_Options_Tab_Support::get_instance();
}

/*
 *
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section( $sections ) {

	$sections[] = [
		'title'  => esc_html__( 'A Section added by hook', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.', 'dropshipping' ) . '</p>',
		// all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		// You dont have to though, leave it blank for default.
		'icon'   => trailingslashit( get_template_directory_uri() ) . 'options/img/glyphicons/glyphicons_062_attach.png',
		// Lets leave this as a blank section, no options just some intro text set above.
		'fields' => [],
	];

	return $sections;

}


/*
 *
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args( $args ) {

	// $args['dev_mode'] = false;

	return $args;

}

/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
 */

function setup_framework_options() {

	$args = [];

	// Set it to dev mode to view the class settings/info in the form - default is false.
	$args['dev_mode'] = false;

	if ( ! MTS_THEME_WHITE_LABEL ) {
		// Setup custom links in the footer for share icons.
		$args['share_icons']['twitter']  = [
			'link'  => 'http://twitter.com/mythemeshopteam',
			'title' => esc_html__( 'Follow Us on Twitter', 'dropshipping' ),
			'img'   => 'fa fa-twitter-square',
		];
		$args['share_icons']['facebook'] = [
			'link'  => 'http://www.facebook.com/mythemeshop',
			'title' => esc_html__( 'Like us on Facebook', 'dropshipping' ),
			'img'   => 'fa fa-facebook-square',
		];
	}

	// Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores.
	$args['opt_name'] = MTS_THEME_NAME;

	// Custom menu title for options page - default is "Options".
	$args['menu_title'] = esc_html__( 'Theme Options', 'dropshipping' );

	// Custom Page Title for options page - default is "Options".
	$args['page_title'] = esc_html__( 'Theme Options', 'dropshipping' );

	// Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options".
	$args['page_slug'] = 'theme_options';

	// custom page location - default 100 - must be unique or will override other items.
	$args['page_position'] = 62;

	// Custom page icon class (used to override the page icon next to heading).
	// $args['page_icon'] = 'icon-themes';.

	if ( ! MTS_THEME_WHITE_LABEL ) {
		// Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition.
		$args['help_tabs'][] = [
			'id'      => 'nhp-opts-1',
			'title'   => esc_html__( 'Support', 'dropshipping' ),
			'content' => '<p>' . sprintf( esc_html__( 'If you are facing any problem with our theme or theme option panel, head over to our %s.', 'dropshipping' ), '<a href="http://community.mythemeshop.com/">' . esc_html__( 'Support Forums', 'dropshipping' ) . '</a>' ) . '</p>',
		];
		$args['help_tabs'][] = [
			'id'      => 'nhp-opts-2',
			'title'   => esc_html__( 'Earn Money', 'dropshipping' ),
			'content' => '<p>' . sprintf( esc_html__( 'Earn 70%% commision on every sale by refering your friends and readers. Join our %s.', 'dropshipping' ), '<a href="http://mythemeshop.com/affiliate-program/">' . esc_html__( 'Affiliate Program', 'dropshipping' ) . '</a>' ) . '</p>',
		];
	}

	$mts_patterns = [
		'nobg'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/nobg.png' ],
		'pattern0'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern0.png' ],
		'pattern1'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern1.png' ],
		'pattern2'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern2.png' ],
		'pattern3'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern3.png' ],
		'pattern4'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern4.png' ],
		'pattern5'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern5.png' ],
		'pattern6'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern6.png' ],
		'pattern7'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern7.png' ],
		'pattern8'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern8.png' ],
		'pattern9'  => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern9.png' ],
		'pattern10' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern10.png' ],
		'pattern11' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern11.png' ],
		'pattern12' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern12.png' ],
		'pattern13' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern13.png' ],
		'pattern14' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern14.png' ],
		'pattern15' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern15.png' ],
		'pattern16' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern16.png' ],
		'pattern17' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern17.png' ],
		'pattern18' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern18.png' ],
		'pattern19' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern19.png' ],
		'pattern20' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern20.png' ],
		'pattern21' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern21.png' ],
		'pattern22' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern22.png' ],
		'pattern23' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern23.png' ],
		'pattern24' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern24.png' ],
		'pattern25' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern25.png' ],
		'pattern26' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern26.png' ],
		'pattern27' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern27.png' ],
		'pattern28' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern28.png' ],
		'pattern29' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern29.png' ],
		'pattern30' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern30.png' ],
		'pattern31' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern31.png' ],
		'pattern32' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern32.png' ],
		'pattern33' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern33.png' ],
		'pattern34' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern34.png' ],
		'pattern35' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern35.png' ],
		'pattern36' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern36.png' ],
		'pattern37' => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/pattern37.png' ],
		'hbg'       => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg.png' ],
		'hbg2'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg2.png' ],
		'hbg3'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg3.png' ],
		'hbg4'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg4.png' ],
		'hbg5'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg5.png' ],
		'hbg6'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg6.png' ],
		'hbg7'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg7.png' ],
		'hbg8'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg8.png' ],
		'hbg9'      => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg9.png' ],
		'hbg10'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg10.png' ],
		'hbg11'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg11.png' ],
		'hbg12'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg12.png' ],
		'hbg13'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg13.png' ],
		'hbg14'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg14.png' ],
		'hbg15'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg15.png' ],
		'hbg16'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg16.png' ],
		'hbg17'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg17.png' ],
		'hbg18'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg18.png' ],
		'hbg19'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg19.png' ],
		'hbg20'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg20.png' ],
		'hbg21'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg21.png' ],
		'hbg22'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg22.png' ],
		'hbg23'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg23.png' ],
		'hbg24'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg24.png' ],
		'hbg25'     => [ 'img' => NHP_OPTIONS_URL . 'img/patterns/hbg25.png' ],
	];

	$exclude_sidebars = [ 'sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-first-5', 'widget-subscribe', 'widget-header','shop-sidebar', 'product-sidebar' ];

	$sections = [];

	$sections[] = [
		'icon'   => 'fa fa-cogs',
		'title'  => esc_html__( 'General Settings', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'This tab contains common setting options which will be applied to the whole theme.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_logo',
				'type'     => 'upload',
				'title'    => esc_html__( 'Logo Image', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Upload your logo using the Upload Button or insert image URL.', 'dropshipping' ),
				'return'   => 'id',
			],
			[
				'id'       => 'mts_favicon',
				'type'     => 'upload',
				'title'    => esc_html__( 'Favicon', 'dropshipping' ),
				'sub_desc' => sprintf( esc_html__( 'Upload a %s image that will represent your website\'s favicon.', 'dropshipping' ), '<strong>32 x 32 px</strong>' ),
				'return'   => 'id',
			],
			[
				'id'       => 'mts_touch_icon',
				'type'     => 'upload',
				'title'    => esc_html__( 'Touch icon', 'dropshipping' ),
				'sub_desc' => sprintf( esc_html__( 'Upload a %s image that will represent your website\'s touch icon for iOS 2.0+ and Android 2.1+ devices.', 'dropshipping' ), '<strong>152 x 152 px</strong>' ),
				'return'   => 'id',
			],
			[
				'id'       => 'mts_metro_icon',
				'type'     => 'upload',
				'title'    => esc_html__( 'Metro icon', 'dropshipping' ),
				'sub_desc' => sprintf( esc_html__( 'Upload a %s image that will represent your website\'s IE 10 Metro tile icon.', 'dropshipping' ), '<strong>144 x 144 px</strong>' ),
				'return'   => 'id',
			],
			[
				'id'       => 'mts_twitter_username',
				'type'     => 'text',
				'title'    => esc_html__( 'Twitter Username', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter your Username here.', 'dropshipping' ),
			],
			[
				'id'       => 'mts_feedburner',
				'type'     => 'text',
				'title'    => esc_html__( 'FeedBurner URL', 'dropshipping' ),
				'sub_desc' => sprintf( esc_html__( 'Enter your FeedBurner\'s URL here, ex: %s and your main feed (http://example.com/feed) will get redirected to the FeedBurner ID entered here.)', 'dropshipping' ), '<strong>http://feeds.feedburner.com/mythemeshop</strong>' ),
				'validate' => 'url',
			],
			[
				'id'       => 'mts_header_code',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Header Code', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Enter the code which you need to place <strong>before closing &lt;/head&gt; tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', 'dropshipping' ), [ 'strong' => '' ] ),
			],
			[
				'id'       => 'mts_analytics_code',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Footer Code', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', 'dropshipping' ), [ 'strong' => '' ] ),
			],
			[
				'id'       => 'mts_ajax_search',
				'type'     => 'button_set',
				'title'    => esc_html__( 'AJAX Quick search', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Enable or disable search results appearing instantly below the search form', 'dropshipping' ),
				'std'      => '0',
			],
			[
				'id'       => 'mts_responsive',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Responsiveness', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'MyThemeShop themes are responsive, which means they adapt to tablet and mobile devices, ensuring that your content is always displayed beautifully no matter what device visitors are using. Enable or disable responsiveness using this option.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_rtl',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Right To Left Language Support', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Enable this option for right-to-left sites.', 'dropshipping' ),
				'std'      => '0',
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-bolt',
		'title'  => esc_html__( 'Performance', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'This tab contains performance-related options which can help speed up your website.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_prefetching',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Prefetching', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Enable or disable prefetching. If user is on homepage, then single page will load faster and if user is on single page, homepage will load faster in modern browsers.', 'dropshipping' ),
				'std'      => '0',
			],
			[
				'id'       => 'mts_async_js',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Async JavaScript', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => sprintf( esc_html__( 'Add %s attribute to script tags to improve page download speed.', 'dropshipping' ), '<code>async</code>' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_remove_ver_params',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Remove ver parameters', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => sprintf( esc_html__( 'Remove %s parameter from CSS and JS file calls. It may improve speed in some browsers which do not cache files having the parameter.', 'dropshipping' ), '<code>ver</code>' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_optimize_wc',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Optimize WooCommerce scripts', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Load WooCommerce scripts and styles only on WooCommerce pages (WooCommerce plugin must be enabled).', 'dropshipping' ),
				'std'      => '1',
			],
			'cache_message' => [
				'id'    => 'mts_cache_message',
				'type'  => 'info',
				'title' => esc_html__( 'Use Cache', 'dropshipping' ),
				// Translators: %1$s = popup link to W3 Total Cache, %2$s = popup link to WP Super Cache.
				'desc'  => sprintf(
					esc_html__( 'A cache plugin can increase page download speed dramatically. We recommend using %1$s or %2$s.', 'dropshipping' ),
					'<a href="https://community.mythemeshop.com/tutorials/article/8-make-your-website-load-faster-using-w3-total-cache-plugin/" target="_blank" title="W3 Total Cache">W3 Total Cache</a>',
					'<a href="' . admin_url( 'plugin-install.php?tab=plugin-information&plugin=wp-super-cache&TB_iframe=true&width=772&height=574' ).'" class="thickbox" title="WP Super Cache">WP Super Cache</a>'
				),
			],
		],
	];

	// Hide cache message on multisite or if a chache plugin is active already.
	if ( is_multisite() || strstr( join( ';', get_option( 'active_plugins' ) ), 'cache' ) ) {
		unset( $sections[1]['fields']['cache_message'] );
	}

	$sections[] = [
		'icon'   => 'fa fa-adjust',
		'title'  => esc_html__( 'Styling Options', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control the visual appearance of your theme, such as colors, layout and patterns, from here.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_color_scheme',
				'type'     => 'color',
				'title'    => esc_html__( 'Color Scheme', 'dropshipping' ),
				'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'dropshipping' ),
				'std'      => '#ef7d5f',
			],
			[
				'id'       => 'mts_layout',
				'type'     => 'radio_img',
				'title'    => esc_html__( 'Layout Style', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Choose the <strong>default sidebar position</strong> for your site. The position of the sidebar for individual posts can be set in the post editor.', 'dropshipping' ), [ 'strong' => '' ] ),
				'options'  => [
					'cslayout' => [ 'img' => NHP_OPTIONS_URL . 'img/layouts/cs.png' ],
					'sclayout' => [ 'img' => NHP_OPTIONS_URL . 'img/layouts/sc.png' ],
				],
				'std'      => 'cslayout',
			],
			[
				'id'       => 'mts_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Site Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
			[
				'id'       => 'mts_custom_css',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Custom CSS', 'dropshipping' ),
				'sub_desc' => esc_html__( 'You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', 'dropshipping' ),
			],
			[
				'id'       => 'mts_lightbox',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Lightbox', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'A lightbox is a stylized pop-up that allows your visitors to view larger versions of images without leaving the current page. You can enable or disable the lightbox here.', 'dropshipping' ),
				'std'      => '1',
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-credit-card',
		'title'  => esc_html__( 'Header', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'From here, you can control the elements of header section.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_sticky_nav',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Floating Navigation Menu', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s.', 'dropshipping' ), '<strong>' . esc_html__( 'Floating Navigation Menu', 'dropshipping' ) . '</strong>' ),
				'std'      => '0',
			],
			[
				'id'       => 'mts_top_description',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Top Navigation Description', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter your top navigation description here.', 'dropshipping' ),
				'std'      => wp_kses( __( '<strong>Free Shipping for all orders of $150</strong>', 'dropshipping' ), [ 'strong' => '' ] ),
			],
			[
				'id'       => 'mts_social_icon_header',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Social Icons', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Use this button to enable/disable header social icon from here.', 'dropshipping' ),
				'options'  => [ '0' => esc_html__( 'Off', 'dropshipping' ), '1' => esc_html__( 'On', 'dropshipping' ) ],
				'std'      => '1',
			],
			[
				'id'        => 'mts_header_social',
				'title'     => esc_html__( 'Add Social Icons', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'Add Social Media icons in header.', 'dropshipping' ),
				'type'      => 'group',
				'groupname' => esc_html__( 'Header Icons', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'    => 'mts_header_icon_title',
						'type'  => 'text',
						'title' => esc_html__( 'Title', 'dropshipping' ),
					],
					[
						'id'    => 'mts_header_icon',
						'type'  => 'icon_select',
						'title' => esc_html__( 'Icon', 'dropshipping' ),
					],
					[
						'id'    => 'mts_header_icon_link',
						'type'  => 'text',
						'title' => esc_html__( 'URL', 'dropshipping' ),
					],
					[
						'id'    => 'mts_header_icon_color',
						'type'  => 'color',
						'title' => esc_html__( 'Color', 'dropshipping' ),
						'std'   => '#ffffff',
					],
				],
				'std'       => [
					'facebook'  => [
						'group_title'           => 'Facebook',
						'group_sort'            => '1',
						'mts_header_icon_title' => 'Facebook',
						'mts_header_icon'       => 'facebook',
						'mts_header_icon_link'  => '#',
						'mts_header_icon_color' => '#ffffff',
					],
					'twitter'   => [
						'group_title'           => 'Twitter',
						'group_sort'            => '2',
						'mts_header_icon_title' => 'Twitter',
						'mts_header_icon'       => 'twitter',
						'mts_header_icon_link'  => '#',
						'mts_header_icon_color' => '#ffffff',
					],
					'instagram' => [
						'group_title'           => 'Instagram',
						'group_sort'            => '3',
						'mts_header_icon_title' => 'Instagram',
						'mts_header_icon'       => 'instagram',
						'mts_header_icon_link'  => '#',
						'mts_header_icon_color' => '#ffffff',
					],
					'youtube'   => [
						'group_title'           => 'You Tube',
						'group_sort'            => '3',
						'mts_header_icon_title' => 'You Tube',
						'mts_header_icon'       => 'youtube',
						'mts_header_icon_link'  => '#',
						'mts_header_icon_color' => '#ffffff',
					],
					'pinterest' => [
						'group_title'           => 'Pinterest',
						'group_sort'            => '3',
						'mts_header_icon_title' => 'Pinterest',
						'mts_header_icon'       => 'pinterest',
						'mts_header_icon_link'  => '#',
						'mts_header_icon_color' => '#ffffff',
					],
				],
			],
			[
				'id'       => 'mts_show_top_nav',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Top Menu', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s.', 'dropshipping' ), '<strong>' . esc_html__( 'Top Navigation Menu', 'dropshipping' ) . '</strong>' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_header_section2',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Logo', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => wp_kses( __( 'Use this button to Show/Hide the <strong>Logo</strong> completely.', 'dropshipping' ), [ 'strong' => '' ] ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_header_search',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Header Search Form', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to Show or Hide <strong>Header Search Form</strong>.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_login_register',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Login/Register', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to show or hide <strong>Header Login/Register</strong>.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_header_wishlist',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Header Wishlist', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to show or hide <strong>Header Wishlist Link</strong>.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_header_cart',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Header Cart', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to show or hide <strong>Header Cart Link</strong>.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_header_links',
				'type'     => 'color',
				'title'    => esc_html__( 'Header Links Color', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Change Header<strong> Login/Register</strong>, <strong>Wishlist</strong>, <strong>Cart</strong> color from here', 'dropshipping' ), [ 'strong' => '' ] ),
				'std'      => '#333333',
			],
			[
				'id'       => 'mts_show_primary_nav',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Primary Menu', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s. Primary Menu is vertically aligned menu', 'dropshipping' ), '<strong>' . esc_html__( 'Primary Navigation Menu', 'dropshipping' ) . '</strong>' ),
				'std'      => '0',
			],
			[
				'id'       => 'mts_nav_title',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Navigation Title', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to enable/disable navigation title with this option.', 'dropshipping' ),
				'std'      => '1',
				'args'     => [ 'hide' => 2 ],
			],
			[
				'id'    => 'mts_nav_title_icon',
				'type'  => 'icon_select',
				'title' => esc_html__( 'Navigation Title Icon', 'dropshipping' ),
				'std'   => 'bars',
			],
			[
				'id'       => 'mts_nav_text',
				'type'     => 'text',
				'title'    => esc_html__( 'Navigation Title Text', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter navigation title here, this title will appear just along with secondary navigation menu and above vertical primary menu.', 'dropshipping' ),
				'std'      => 'Browse Categories',
			],
			[
				'id'       => 'mts_show_secondary_nav',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Secondary Menu', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s.', 'dropshipping' ), '<strong>' . esc_html__( 'Secondary Navigation Menu', 'dropshipping' ) . '</strong>' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_header_buttons_section',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Show Header Custom Buttons', 'dropshipping' ),
				'sub_desc' => sprintf( esc_html__( 'Use this button to show %s.', 'dropshipping' ), '<strong>' . esc_html__( 'Header Custom Buttons', 'dropshipping' ) . '</strong>' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'std'      => '0',
				'args'     => [ 'hide' => ' 1' ],
			],
			[
				'id'        => 'mts_header_buttons',
				'title'     => esc_html__( 'Add Custom Buttons', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'Add links in your buttons to redirect to any page.', 'dropshipping' ),
				'type'      => 'group',
				'groupname' => esc_html__( 'Custom Button', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'    => 'mts_header_button_title',
						'type'  => 'text',
						'title' => esc_html__( 'Title', 'dropshipping' ),
					],
					[
						'id'    => 'mts_header_button_link',
						'type'  => 'text',
						'title' => esc_html__( 'URL', 'dropshipping' ),
					],
					[
						'id'    => 'mts_header_button_color',
						'type'  => 'color',
						'title' => esc_html__( 'Button Color', 'dropshipping' ),
						'std'   => '#333333'
					],
				],
			],
			[
				'id'       => 'mts_top_header_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Top Header Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set top header background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ef7d5f',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
			[
				'id'       => 'mts_header_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Header Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set header background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
			[
				'id'       => 'mts_bottom_header_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Bottom Header Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set bottom header & primary navigation background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-table',
		'title'  => esc_html__( 'Footer', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'From here, you can control the elements of Footer section.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_first_footer',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Footer', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Use this button to enable/disable footer widget with this option.', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'std'      => '0',
			],
			[
				'id'       => 'mts_first_footer_num',
				'type'     => 'button_set',
				'class'    => 'green',
				'title'    => esc_html__( 'Footer Layout', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Choose the number of widget areas in the <strong>footer</strong>', 'dropshipping' ), [ 'strong' => '' ] ),
				'options'  => [
					'3' => esc_html__( '3 Widgets', 'dropshipping' ),
					'4' => esc_html__( '4 Widgets', 'dropshipping' ),
					'5' => esc_html__( '5 Widgets', 'dropshipping' ),
				],
				'std'      => '5',
			],
			[
				'id'       => 'mts_copyrights',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Copyrights Text', 'dropshipping' ),
				'sub_desc' => esc_html__( 'You can change or remove our link from footer and use your own custom text.', 'dropshipping' ) . ( MTS_THEME_WHITE_LABEL ? '' : wp_kses( __( '(You can also use your affiliate link to <strong>earn 70% of sales</strong>. Ex: <a href="https://mythemeshop.com/go/aff/aff" target="_blank">https://mythemeshop.com/?ref=username</a>)', 'dropshipping' ), [ 'strong' => '', 'a' => [ 'href' => [], 'target' => [] ] ] ) ),
				'std'      => MTS_THEME_WHITE_LABEL ? null : sprintf( esc_html__( 'Theme by %s', 'dropshipping' ), '<a href="http://mythemeshop.com/" rel="nofollow">MyThemeShop</a>' ),
			],
			[
				'id'       => 'mts_copyright_link_color',
				'type'     => 'color',
				'title'    => esc_html__( 'Copyright Links Color', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Change copyright link color with this option. Copyright text color can be changed from typography tabs.', 'dropshipping' ),
				'std'      => '#3f3f3f',
			],
			[
				'id'        => 'mts_accepted_payment_method_icons',
				'type'      => 'group',
				'title'     => esc_html__( 'Accepted Payment Methods Icons', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'Add accepted payment methods icons in the footer area.', 'dropshipping' ),
				'groupname' => esc_html__( 'Payment Method Icon', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'       => 'mts_accepted_payment_method_title',
						'type'     => 'text',
						'title'    => esc_html__( 'Payment Method', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Enter the title for this payment method.', 'dropshipping' ),
					],
					[
						'id'       => 'mts_accepted_payment_method_icon',
						'type'     => 'icon_select',
						'title'    => esc_html__( 'Payment Method Icon', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Select icon for this payment method.', 'dropshipping' ),
						'subset'   => esc_html__( 'Payment Icons', 'dropshipping' ),
					],
					[
						'id'       => 'mts_accepted_payment_method_image',
						'type'     => 'upload',
						'title'    => esc_html__( 'Custom Image ( Recommended size: 32x20px )', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Use this option if you want to use custom image insteady of pre-defined icons.', 'dropshipping' ),
					],
				],
				'std'       => [
					'1' => [
						'group_title'                       => '',
						'group_sort'                        => '1',
						'mts_accepted_payment_method_title' => 'Visa',
						'mts_accepted_payment_method_icon'  => 'cc-visa',
						'mts_accepted_payment_method_image' => '',
					],
					'2' => [
						'group_title'                       => '',
						'group_sort'                        => '2',
						'mts_accepted_payment_method_title' => 'MasterCard',
						'mts_accepted_payment_method_icon'  => 'cc-mastercard',
						'mts_accepted_payment_method_image' => '',
					],
					'3' => [
						'group_title'                       => '',
						'group_sort'                        => '3',
						'mts_accepted_payment_method_title' => 'Paypal',
						'mts_accepted_payment_method_icon'  => 'cc-paypal',
						'mts_accepted_payment_method_image' => '',
					],
					'4' => [
						'group_title'                      => '',
						'group_sort'                       => '4',
						'mts_accepted_payment_method_title' => 'Discover',
						'mts_accepted_payment_method_icon' => 'cc-discover',
						'mts_accepted_payment_method_image' => '',
					],
					'5' => [
						'group_title'                       => '',
						'group_sort'                        => '5',
						'mts_accepted_payment_method_title' => 'Amex',
						'mts_accepted_payment_method_icon'  => 'cc-amex',
						'mts_accepted_payment_method_image' => '',
					],
					'6' => [
						'group_title'                       => '',
						'group_sort'                        => '6',
						'mts_accepted_payment_method_title' => 'Stripe',
						'mts_accepted_payment_method_icon'  => 'cc-stripe',
						'mts_accepted_payment_method_image' => '',
					],
				],
			],
			[
				'id'       => 'mts_footer_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Footer Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set footer background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'HomePage Layouts', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'This tab contains common setting options which will be applied to the whole theme.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_homepage_layout',
				'type'     => 'layout',
				'title'    => esc_html__( 'Homepage Layout Manager', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Organize how you want the layout to appear on the homepage', 'dropshipping' ),
				'options'  => [
					'enabled'  => [
						'featured-categories' => esc_html__( 'Featured Categories', 'dropshipping' ),
						'featured-tabs'       => esc_html__( 'Featured Tabs', 'dropshipping' ),
						'product-slider'      => esc_html__( 'Product Slider', 'dropshipping' ),
						'call-to-action'      => esc_html__( 'Call to action', 'dropshipping' ),
						'subscribe'           => esc_html__( 'Newsletter', 'dropshipping' ),
						'blog-section'        => esc_html__( 'Blog Section', 'dropshipping' ),
						'brands-carousel'     => esc_html__( 'Brand Carousel', 'dropshipping' ),
						'footer-carousel'     => esc_html__( 'Footer Carousel', 'dropshipping' )
					],
					'disabled' => [],
				],
				'std'      => [
					'enabled'  => [
						'featured-categories' => esc_html__( 'Featured Categories', 'dropshipping' ),
						'featured-tabs'       => esc_html__( 'Featured Tabs', 'dropshipping' ),
						'product-slider'      => esc_html__( 'Product Slider', 'dropshipping' ),
						'call-to-action'      => esc_html__( 'Call to action', 'dropshipping' ),
						'subscribe'           => esc_html__( 'Newsletter', 'dropshipping' ),
						'blog-section'        => esc_html__( 'Blog Section', 'dropshipping' ),
						'brands-carousel'     => esc_html__( 'Brand Carousel', 'dropshipping' ),
						'footer-carousel'     => esc_html__( 'Footer Carousel', 'dropshipping' )
					],
					'disabled' => [],
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Fetaured Slider', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to Featured Slider.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_featured_show_slider',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Featured Slider', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => wp_kses( __( '<strong>Enable or Disable</strong> featured slider with this button.', 'dropshipping' ), [ 'strong' => '' ] ),
				'std'      => '0',
				'args'     => [ 'hide' => 1 ],
			],
			[
				'id'        => 'mts_featured_slider',
				'type'      => 'group',
				'title'     => esc_html__( 'Featured Slider', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'With this option you can set up a featured slider with upload image option and adding other stuffs.', 'dropshipping' ),
				'groupname' => esc_html__( 'product', 'dropshipping' ), // Single item name.
				'subfields' => [
					[
						'id'       => 'mts_featured_slider_image',
						'type'     => 'upload',
						'title'    => esc_html__( 'Image', 'dropshipping' ),
						'sub_desc' => wp_kses( __( 'Upload or select an image for this slide. <strong>Recommended size 700x495 pixel.</strong>', 'dropshipping' ), [ 'strong' => '' ] ),
						'return'   => 'url',
					],
					[
						'id'       => 'mts_featured_slider_type',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Category', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Enter product category like chair, cloth, table, album etc. or some additional text.', 'dropshipping' ),
						'std'      => 'Best',
					],
					[
						'id'       => 'mts_featured_slider_title',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Title', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Enter Product Title here', 'dropshipping' ),
						'std'      => 'Rock Chair.',
					],
					[
						'id'       => 'mts_featured_slider_description',
						'type'     => 'textarea',
						'title'    => esc_html__( 'Product Description', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Add product description here.', 'dropshipping' ),
						'std'      => wp_kses( __( 'Semper vulputate aliquam curae condimentum <br>quisque gravida fusce convallis arcu cum at. ', 'dropshipping' ), [ 'br' => '' ] ),
					],
					[
						'id'       => 'mts_featured_slider_amount',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Amount', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Add product amount here.', 'dropshipping' ),
						'std'      => '$199.00',
					],
					[
						'id'       => 'mts_featured_slider_link',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Link', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Add product URL here.', 'dropshipping' ),
						'std'      => '#',
					],
					[
						'id'       => 'mts_featured_slider_text_color',
						'type'     => 'color',
						'title'    => esc_html__( 'Slider Text Color', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Change featured slider title color, description color, amount color from here.', 'dropshipping' ),
						'std'      => '#333333',
					],
					[
						'id'       => 'mts_featured_slider_bg_color',
						'type'     => 'color',
						'title'    => esc_html__( 'Slider Background Color', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Change featured slider background color from here.', 'dropshipping' ),
						'std'      => '#f8f8f8',
					],
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Featured Categories', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to Featured Categories.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_featured_category_subheading',
				'type'     => 'text',
				'title'    => esc_html__( 'Featured Categories Subheading', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter featured categories section sub heading here.', 'dropshipping' ),
				'std'      => 'Dropshipping Collections',
			],
			[
				'id'       => 'mts_featured_category_heading',
				'type'     => 'text',
				'title'    => esc_html__( 'Featured Categories Heading', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter featured categories section heading here.', 'dropshipping' ),
				'std'      => 'Featured Categories',
			],
			[
				'id'       => 'mts_featured_category_description',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Featured Categories Description', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter featured categories description here.', 'dropshipping' ),
				'std'      => 'Dropshipping is a powerful eCommerce theme for WordPress.',
			],
			[
				'id'        => 'mts_featured_product_categories',
				'type'      => 'group',
				'title'     => esc_html__( 'Product Categories', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'Select product categories appearing on the homepage.', 'dropshipping' ),
				'groupname' => esc_html__( 'Product Category', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'       => 'mts_featured_product_category',
						'type'     => 'cats_select_custompost',
						'tax'      => 'product_cat',
						'title'    => esc_html__( 'Product Category', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Select a product category or the latest posts for this section', 'dropshipping' ),
					],
					[
						'id'    => 'mts_featured_product_category_title_color',
						'type'  => 'color',
						'title' => esc_html__( 'Title Color', 'dropshipping' ),
						'std'   => '#2a2a2a',
					],
					[
						'id'    => 'mts_featured_product_category_count_color',
						'type'  => 'color',
						'title' => esc_html__( 'Count Color', 'dropshipping' ),
						'std'   => '#8e8e8e',
					],
				],
				'std'       => [],
			],
			[
				'id'       => 'mts_featured_cat_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Featured Category Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set featured category section background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Featured Tabs', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to Featured Tabs.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_featured_tabs_subheading',
				'type'     => 'text',
				'title'    => esc_html__( 'Featured Tabs Subheading', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter featured tabs section sub heading here.', 'dropshipping' ),
				'std'      => 'Dropshipping Accessories',
			],
			[
				'id'       => 'mts_featured_tabs_heading',
				'type'     => 'text',
				'title'    => esc_html__( 'Featured Tabs Heading', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter featured tabs section heading here.', 'dropshipping' ),
				'std'      => 'Hottest Collections',
			],
			[
				'id'       => 'mts_featured_tabs_description',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Featured Tabs Description', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter featured tabs description here.', 'dropshipping' ),
				'std'      => 'Visit now to check out our latest mind blowing collections.',
			],
			[
				'id'       => 'mts_home_tabs',
				'type'     => 'layout',
				'title'    => esc_html__( 'Product tabs to Show', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Organize how you want the tabs on homepage to appear', 'dropshipping' ),
				'options'  => [
					'enabled'  => [
						'best_sellers' => esc_html__( 'Best sellers', 'dropshipping' ),
						'new_arrivals' => esc_html__( 'New Arrivals', 'dropshipping' ),
						'top_rated'    => esc_html__( 'Top Rated', 'dropshipping' ),
					],
					'disabled' => [],
				],
				'std'      => [
					'enabled'  => [
						'best_sellers' => esc_html__( 'Best sellers', 'dropshipping' ),
						'new_arrivals' => esc_html__( 'New Arrivals', 'dropshipping' ),
						'top_rated'    => esc_html__( 'Top Rated', 'dropshipping' ),
					],
					'disabled' => [],
				],
			],
			[
				'id'       => 'mts_home_tabs_products',
				'type'     => 'text',
				'class'    => 'small-text',
				'title'    => esc_html__( 'Number of Products', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter the number of products to show in this section.', 'dropshipping' ),
				'std'      => '8',
				'args'     => [ 'type' => 'number' ],
			],
			[
				'id'       => 'mts_featured_tabs_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Featured Tabs Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set featured tabs section background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Product Slider', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to product slider.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'        => 'mts_product_slider',
				'type'      => 'group',
				'title'     => esc_html__( 'Product Slider', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'With this option you can set up a product slider with uploading product image and by adding other stuffs.', 'dropshipping' ),
				'groupname' => esc_html__( 'product', 'dropshipping' ), // Single item name.
				'subfields' => [
					[
						'id'       => 'mts_product_slider_image',
						'type'     => 'upload',
						'title'    => esc_html__( 'Image', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Upload or select an image for this slide', 'dropshipping' ),
						'sub_desc' => wp_kses( __( 'Upload or select an image for this slide. Recommended Size <strong>630x387px</strong>', 'dropshipping' ), [ 'strong' => '' ] ),
						'return'   => 'id',
					],
					[
						'id'       => 'mts_product_slider_type',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Category', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Enter product category like chair, cloth, table etc. or some additional text.', 'dropshipping' ),
						'std'      => 'Product Landing Page',
					],
					[
						'id'       => 'mts_product_slider_title',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Title', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Enter Product Title here', 'dropshipping' ),
						'std'      => 'Vitra Chair- Classic Design',
					],
					[
						'id'       => 'mts_product_slider_amount',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Amount', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Add product amount here.', 'dropshipping' ),
						'std'      => '$1999.00',
					],
					[
						'id'       => 'mts_product_slider_button',
						'type'     => 'text',
						'title'    => esc_html__( 'Button Text', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Button text of the slide', 'dropshipping' ),
						'std'      => esc_html__( 'More Details', 'dropshipping' ),
					],
					[
						'id'       => 'mts_product_slider_button_link',
						'type'     => 'text',
						'title'    => esc_html__( 'Product Link', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Add product URL here.', 'dropshipping' ),
						'std'      => '#',
					],
				],
			],
			[
				'id'       => 'mts_product_slider_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Product Slider Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set product slider section background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ef7d5f',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Call To Action', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to Call To Action from here', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_call_to_action_title1',
				'type'     => 'text',
				'title'    => esc_html__( 'Call to Action Title1', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter Call to Action Title1 from here. This title text will be light color and normal font-weight.', 'dropshipping' ),
				'std'      => 'Get our latest catalogue',
			],
			[
				'id'       => 'mts_call_to_action_title2',
				'type'     => 'text',
				'title'    => esc_html__( 'Call to Action Title2', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter Call to Action Title 2 from here. This title text will be dark color and bold font-weight.', 'dropshipping' ),
				'std'      => 'Free monthly showcasing',
			],
			[
				'id'       => 'mts_call_to_action_description',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Call to Action Description', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter Call to Action description from here.', 'dropshipping' ),
				'std'      => 'Quisque tincidunt felis magna. Donec fermentum, metus laoreet fringilla fringilla, neque tellus dictum felis, eget tempus est tellus sed urna finibus nisi purus, eget feugiat nibh lobortis vel tortor et cursus tristique.',
			],
			[
				'id'        => 'mts_call_to_action_buttons',
				'title'     => esc_html__( 'Add Custom Buttons', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'Add links in your buttons to redirect to any page.', 'dropshipping' ),
				'type'      => 'group',
				'groupname' => esc_html__( 'Custom Button', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'    => 'mts_call_to_action_button_title',
						'type'  => 'text',
						'title' => esc_html__( 'Title', 'dropshipping' ),
					],
					[
						'id'    => 'mts_call_to_action_button_link',
						'type'  => 'text',
						'title' => esc_html__( 'URL', 'dropshipping' ),
					],
					[
						'id'    => 'mts_call_to_action_button_bg',
						'type'  => 'color',
						'title' => esc_html__( 'Button background', 'dropshipping' ),
						'std'   => '#ef7d5f',
					],
					[
						'id'    => 'mts_call_to_action_button_color',
						'type'  => 'color',
						'title' => esc_html__( 'Button color', 'dropshipping' ),
						'std'   => '#ffffff',
					],
					[
						'id'    => 'mts_call_to_action_button_border',
						'type'  => 'color',
						'title' => esc_html__( 'Button border color', 'dropshipping' ),
						'std'   => '#e9e9e9',
					],
				],
			],
			[
				'id'       => 'mts_call_to_action_bg',
				'type'     => 'background',
				'title'    => esc_html__( 'Call to Action Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set Call To Action background color/pattern/custom image from here', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => 'upload',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'upload',
					'image_pattern' => 'nobg',
					'image_upload'  => get_template_directory_uri() . '/images/about-us.jpg',
					'repeat'        => 'no-repeat',
					'attachment'    => 'scroll',
					'position'      => 'center center',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Newsletter Box', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to newsletter box section from here.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'      => 'mts_newsletter_box_bg',
				'type'    => 'background',
				'title'   => esc_html__( 'Newsletter Background', 'dropshipping' ),
				'options' => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => 'upload',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'    => [
					'color'         => '#ffffff',
					'use'           => 'upload',
					'image_pattern' => 'nobg',
					'image_upload'  => get_template_directory_uri() . '/images/newsletter.jpg',
					'repeat'        => 'no-repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'default',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Blog Section', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to blog section from here.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_blog_section_subheading',
				'type'     => 'text',
				'title'    => esc_html__( 'Blog Section Subheading', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter blog section sub heading here.', 'dropshipping' ),
				'std'      => 'Top new in this week',
			],
			[
				'id'       => 'mts_blog_section_heading',
				'type'     => 'text',
				'title'    => esc_html__( 'Blog Section Heading', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter blog section heading here.', 'dropshipping' ),
				'std'      => 'Our Latest News',
			],
			[
				'id'       => 'mts_blog_section_description',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Blog Section Description', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter blog section description here.', 'dropshipping' ),
				'std'      => 'Latest trends and inspiration in dropshipping.',
			],
			[
				'id'       => 'mts_blog_slider_num',
				'type'     => 'text',
				'class'    => 'small-text',
				'title'    => esc_html__( 'Number of posts', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter the number of posts to show in the slider', 'dropshipping' ),
				'std'      => '3',
				'args'     => [ 'type' => 'number' ],
			],
			[
				'id'       => 'mts_home_blog_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Blog Section Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set blog section background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Brand Carousel', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to brand carousel section from here.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_featured_brands',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Brands Carousel', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to enable/disable brands carousel, This brands carousel will be shown above Footer', 'dropshipping' ),
				'std'      => '0',
				'args'     => [ 'hide' => 2 ],
			],
			[
				'id'        => 'mts_brands_carousel',
				'type'      => 'group',
				'title'     => esc_html__( 'Brands Items', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'With this option you can set up a carousel with custom images and links.', 'dropshipping' ),
				'groupname' => esc_html__( 'Brand', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'       => 'mts_brands_carousel_title',
						'type'     => 'text',
						'title'    => esc_html__( 'Title', 'dropshipping' ),
						'sub_desc' => esc_html__( 'This title will not be shown', 'dropshipping' ),
					],
					[
						'id'       => 'mts_brands_carousel_image',
						'type'     => 'upload',
						'title'    => esc_html__( 'Logo Image', 'dropshipping' ),
						'sub_desc' => wp_kses( __( 'Upload or select a client logo image<strong>(158x60px)</strong> for this client logo carousel', 'dropshipping' ), [ 'strong' => '' ] ),
						'return'   => 'url',
					],
					[
						'id'       => 'mts_brands_carousel_link',
						'type'     => 'text',
						'title'    => esc_html__( 'Link', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Insert a link URL for the carousel', 'dropshipping' ),
						'std'      => '#',
					],
				],
			],
			[
				'id'       => 'mts_brands_carousel_bg',
				'type'     => 'background',
				'title'    => esc_html__( 'Brands Carousel Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set brands carousel background color/pattern/custom image section from here', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Footer Carousel', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Control settings related to footer carousel section from here. Footer Carousel will be shown on homepage.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_featured_footer_carousel',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Footer Carousel', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to enable/disable footer carousel, This brands carousel will be shown above Footer', 'dropshipping' ),
				'std'      => '0',
				'args'     => [ 'hide' => 7 ],
			],
			[
				'id'       => 'mts_footer_carousel_subheading',
				'type'     => 'text',
				'title'    => esc_html__( 'Footer Carousel Subheading', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter footer carousel sub heading here.', 'dropshipping' ),
				'std'      => 'Prebuilt Layouts',
			],
			[
				'id'       => 'mts_footer_carousel_title',
				'type'     => 'text',
				'title'    => esc_html__( 'Footer Carousel Title', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter footer carousel title here.', 'dropshipping' ),
				'std'      => 'Dropshipping Demos',
			],
			[
				'id'       => 'mts_footer_carousel_description',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Footer Carousel Description', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter footer carousel description here.', 'dropshipping' ),
				'std'      => 'High-quality demos and layouts.',
			],
			[
				'id'       => 'mts_footer_carousel_link_text',
				'type'     => 'text',
				'title'    => esc_html__( 'Footer Carousel URL text', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter footer carousel URL text here.', 'dropshipping' ),
				'std'      => 'View All',
			],
			[
				'id'       => 'mts_footer_carousel_link',
				'type'     => 'text',
				'title'    => esc_html__( 'Footer Carousel URL', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter footer carousel URL here.', 'dropshipping' ),
				'std'      => '#',
			],
			[
				'id'        => 'mts_footer_carousel',
				'type'      => 'group',
				'title'     => esc_html__( 'Carousel Items', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'With this option you can set up a carousel with custom images and links.', 'dropshipping' ),
				'groupname' => esc_html__( 'carousel', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'       => 'mts_footer_carousel_title',
						'type'     => 'text',
						'title'    => esc_html__( 'Title', 'dropshipping' ),
						'sub_desc' => esc_html__( 'This title will not be shown', 'dropshipping' ),
					],
					[
						'id'       => 'mts_footer_carousel_image',
						'type'     => 'upload',
						'title'    => esc_html__( 'Logo Image', 'dropshipping' ),
						'sub_desc' => wp_kses( __( 'Upload or select a client logo image<strong>(184x144px)</strong> for the footer carousel', 'dropshipping' ), [ 'strong' => '' ] ),
						'return'   => 'url',
					],
					[
						'id'       => 'mts_footer_carousel_link',
						'type'     => 'text',
						'title'    => esc_html__( 'Link', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Insert a link URL for the carousel', 'dropshipping' ),
						'std'      => '#',
					],
				],
			],
			[
				'id'       => 'mts_footer_carousel_bg',
				'type'     => 'background',
				'title'    => esc_html__( 'Footer Carousel Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set brands carousel background color/pattern/custom image section from here', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#fbfbfb',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Shop Page', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'From here, you can control the elements of the shop page', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_shop_title_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Shop Title Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set shop page, shop archive page title background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => 'upload',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#0a0a0a',
					'use'           => 'upload',
					'image_pattern' => 'nobg',
					'image_upload'  => get_template_directory_uri() . '/images/shop-title.jpg',
					'repeat'        => 'no-repeat',
					'attachment'    => 'scroll',
					'position'      => 'center center',
					'size'          => 'cover',
					'gradient'	    => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
			[
				'id'        => 'mts_shop_product_categories',
				'type'      => 'group',
				'title'     => esc_html__( 'Shop Product Categories', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'Select product categories appearing on the shop page.', 'dropshipping' ),
				'groupname' => esc_html__( 'Product Category', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'       => 'mts_shop_product_category',
						'type'     => 'cats_select_custompost',
						'tax'      => 'product_cat',
						'title'    => esc_html__( 'Product Category', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Select a product category or the latest posts for this section', 'dropshipping' ),
					],
					[
						'id'    => 'mts_shop_product_icon',
						'type'  => 'icon_select',
						'title' => esc_html__( 'Icon', 'dropshipping' ),
					],
				],
				'std'       => [
					'1' => [
						'group_title'           => '',
						'group_sort'            => '1',
						'mts_shop_product_icon' => 'adjust',
					],
				],
			],
			[
				'id'       => 'mts_shop_products',
				'type'     => 'text',
				'title'    => esc_html__( 'No. of Products', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter the total number of products which you want to show on shop page (WooCommerce plugin must be enabled).', 'dropshipping' ),
				'validate' => 'numeric',
				'std'      => '12',
				'class'    => 'small-text',
			],
			[
				'id'       => 'mts_wishlist',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Wishlist Feature', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to enable/disable wishlist feature. Page with "Wishlist" title and "Wishlist Page" template is required.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_mark_new_products',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Mark New Products', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to enable/disable "New" marking on latest products.', 'dropshipping' ),
				'std'      => '0',
			],
			[
				'id'       => 'mts_new_products_time',
				'type'     => 'text',
				'title'    => esc_html__( 'No. of days the product is considered new', 'dropshipping' ),
				'sub_desc' => esc_html__( 'No. of days the product is considered new.', 'dropshipping' ),
				'validate' => 'numeric',
				'std'      => '30',
				'class'    => 'small-text',
			],
		],
	];

	$sections[] = [
		'icon'   => '',
		'title'  => esc_html__( 'Shop Single Page', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'From here, you can control the elements of the shop page', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_single_product_tabs',
				'type'     => 'layout',
				'title'    => esc_html__( 'Single Product Tabs', 'dropshipping' ),
				'sub_desc' => esc_html__ ( 'Organize how you want tabs to appear on single product', 'dropshipping' ),
				'options'  => [
					'enabled'  => [
						'description'            => esc_html__( 'Description', 'dropshipping' ),
						'additional_information' => esc_html__( 'Additional Information', 'dropshipping' ),
						'reviews'                => esc_html__( 'Reviews', 'dropshipping' ),
						'about_brand'            => esc_html__( 'About Brand', 'dropshipping' ),
						'shipping_delivery'      => esc_html__( 'Shipping & Delivery', 'dropshipping' ),
					],
					'disabled' => [],
				],
				'std'      => [
					'enabled'  => [
						'description'            => esc_html__( 'Description', 'dropshipping' ),
						'additional_information' => esc_html__( 'Additional Information', 'dropshipping' ),
						'reviews'                => esc_html__( 'Reviews', 'dropshipping' ),
						'about_brand'            => esc_html__( 'About Brand', 'dropshipping' ),
						'shipping_delivery'      => esc_html__( 'Shipping & Delivery', 'dropshipping' ),
					],
					'disabled' => [],
				],
			],
			[
				'id'       => 'mts_about_brand_content',
				'type'     => 'editor',
				'title'    => esc_html__( 'Edit About Brand', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Write/Edit About your favourite brands from here, This decription will be shown in single product About Brand tab section', 'dropshipping' ),
				'std'      => wp_kses( __( '<strong>Edit this from Woocommerce About Brand Tab</strong>', 'dropshipping' ), [ 'strong' => '' ] ),
			],
			[
				'id'       => 'mts_shipping_delivery_content',
				'type'     => 'editor',
				'title'    => esc_html__( 'Edit Shipping & Delivery', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Write/Edit About shipping & delivery method from here. This decription will be shown in single product Shipping & Delivery tab section', 'dropshipping' ),
				'std'      => wp_kses( __( '<strong>Edit this from Woocommerce Shipping & Delivery Tab</strong>', 'dropshipping' ), [ 'strong' => '' ] ),
			],
			[
				'id'       => 'mts_related_products',
				'type'     => 'button_set_hide_below',
				'title'    => esc_html__( 'Show Related Products Slider', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to enable/disable related products carousel on single product', 'dropshipping' ),
				'std'      => '1',
				'args'     => [ 'hide' => 1 ],
			],
			[
				'id'       => 'mts_related_products_num',
				'type'     => 'text',
				'title'    => esc_html__( 'No. of Related Products', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter the total number of related products.', 'dropshipping' ),
				'validate' => 'numeric',
				'std'      => '8',
				'class'    => 'small-text',
			],
			[
				'id'       => 'mts_upsells_slider',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show UpSells Product Slider', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Use this button to show upsells product slider. UpSells Slider will be shown on single product page.', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'std'      => '1',
			],
			[
				'id'       => 'mts_checkout_progress',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Checkout Progress', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to enable/disable checkout progress from cart/checkout/order-received pages.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_cross_sells_slider',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Cross Sells Product Slider', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Use this button to show cross sells product slider. Cross Sells Slider will be shown on checkout pages.', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'std'      => '1',
			],
			[
				'id'       => 'mts_shop_single_title_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Shop Single Title Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set shop single page title background color, pattern and image from here. This will change the background color form cart/checkout/myaccount/order-received etc.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'        => [],
					'attachment'    => [],
					'position'      => [],
					'size'          => [],
					'gradient'      => '',
					'parallax'      => [],
				],
				'std'      => [
					'color'         => '#0a0a0a',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'center center',
					'size'          => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'      => '0',
				],
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-list',
		'title'  => esc_html__( 'Blog Page', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'From here, you can control the elements of the homepage.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_blog_title_background',
				'type'     => 'background',
				'title'    => esc_html__( 'Page Title Background', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Set page title background color, pattern and image from here.', 'dropshipping' ),
				'options'  => [
					'color'         => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => 'upload',
					'repeat'        => [],
					'attachment'    => [],
					'position'	    => [],
					'size'		    => [],
					'gradient'	    => '',
					'parallax'	    => [],
				],
				'std'      => [
					'color'         => '#0a0a0a',
					'use'           => 'upload',
					'image_pattern' => 'nobg',
					'image_upload'  => get_template_directory_uri() . '/images/blog-title.jpg',
					'repeat'        => 'no-repeat',
					'attachment'    => 'scroll',
					'position'	    => 'center center',
					'size'		    => 'cover',
					'gradient'      => [ 'from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ],
					'parallax'	    => '0',
				],
			],
			[
				'id'        => 'mts_featured_categories',
				'type'      => 'group',
				'title'     => esc_html__( 'Featured Categories', 'dropshipping' ),
				'sub_desc'  => esc_html__( 'Select categories appearing on the homepage.', 'dropshipping' ),
				'groupname' => esc_html__( 'Section', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'       => 'mts_featured_category',
						'type'     => 'cats_select',
						'title'    => esc_html__( 'Category', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Select a category or the latest posts for this section', 'dropshipping' ),
						'std'      => 'latest',
						'args'     => [ 'include_latest' => 1, 'hide_empty' => 0 ],
					],
					[
						'id'       => 'mts_featured_category_postsnum',
						'type'     => 'text',
						'class'    => 'small-text',
						'title'    => esc_html__( 'Number of posts', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Enter the number of posts to show in this section.', 'dropshipping' ),
						'std'      => '3',
						'args'     => [ 'type' => 'number' ],
					],
				],
				'std'       => [
					'1' => [
						'group_title'                    => '',
						'group_sort'                     => '1',
						'mts_featured_category'          => 'latest',
						'mts_featured_category_postsnum' => get_option( 'posts_per_page' ),
					],
				],
			],
			[
				'id'       => 'mts_blog_posts_layout',
				'type'     => 'radio_img',
				'title'    => esc_html__( 'Blog Posts Style', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Choose the <strong>blog posts layout</strong> for your site.', 'dropshipping' ), [ 'strong' => '' ] ),
				'options'  => [
					'default' => [ 'img' => NHP_OPTIONS_URL . 'img/layouts/blog-grid-3.png' ],
					'grid-2'  => [ 'img' => NHP_OPTIONS_URL . 'img/layouts/blog-grid-2.png' ],
					'grid-1'  => [ 'img' => NHP_OPTIONS_URL . 'img/layouts/blog-grid-1.png' ],
				],
				'std'      => 'default',
			],
			[
				'id'       => 'mts_home_meta_info_enable',
				'type'     => 'multi_checkbox',
				'title'    => esc_html__( 'HomePage Post Meta Info', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on the homepage', 'dropshipping' ),
				'options'  => [
					'time'     => esc_html__( 'Enable Time/Date', 'dropshipping' ),
					'category' => esc_html__( 'Enable Category', 'dropshipping' ),
					'author'   => esc_html__( 'Enable Author Name', 'dropshipping' ),
					'comment'  => esc_html__( 'Enable Comments', 'dropshipping' ),
				],
				'std'      => [
					'time'     => '1',
					'category' => '1',
					'author'   => '1',
					'comment'  => '1',
				],
			],
			[
				'id'       => 'mts_date_layout',
				'type'     => 'radio_img',
				'title'    => esc_html__( 'Date Formate Style', 'dropshipping' ),
				'sub_desc' => '<p class="description">' . sprintf( esc_html__( 'Choose the date style for your Blog Posts. You can manage second style from %s.', 'dropshipping' ), '<a href="options-general.php"><b>' . esc_html__( 'here', 'dropshipping' ) . '</b></a>' ) . '<br></p>',
				'options'  => [
					'datebig'   => [ 'img' => NHP_OPTIONS_URL . 'img/layouts/date-big.png' ],
					'datesmall' => [ 'img' => NHP_OPTIONS_URL . 'img/layouts/date-default.png' ],
				],
				'std'      => 'datebig',
			],
			[
				'id'       => 'mts_pagenavigation_type',
				'type'     => 'radio',
				'title'    => esc_html__( 'Pagination Type', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select pagination type.', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Next / Previous', 'dropshipping' ),
					'1' => esc_html__( 'Default Numbered (1 2 3 4...)', 'dropshipping' ),
					'2' => esc_html__( 'AJAX (Load More Button)', 'dropshipping' ),
					'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'dropshipping' ),
				],
				'std'      => '1',
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-file-text',
		'title'  => esc_html__( 'Single Posts', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'From here, you can control the appearance and functionality of your single posts page.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_single_post_layout',
				'type'     => 'layout2',
				'title'    => esc_html__( 'Single Post Layout', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Customize the look of single posts', 'dropshipping' ),
				'options'  => [
					'enabled'  => [
						'content'       => [
							'label'     => esc_html__( 'Post Content', 'dropshipping' ),
							'subfields'	=> [],
						],
						'author'        => [
							'label'     => esc_html__( 'Author Box', 'dropshipping' ),
							'subfields' => [],
						],
						'social-share'  => [
							'label'     => esc_html__( 'Social Share & Tags', 'dropshipping' ),
							'subfields' => [
								[
									'id'       => 'mts_tags',
									'type'     => 'button_set',
									'title'    => esc_html__( 'Tags', 'dropshipping' ),
									'options'  => [
										'0' => esc_html__( 'Off', 'dropshipping' ),
										'1' => esc_html__( 'On', 'dropshipping' ),
									],
									'sub_desc' => esc_html__( 'Use this button to show tags along with the Social Share icons.', 'dropshipping' ),
									'std'      => '1',
								],
								[
									'id'   => 'mts_social_info',
									'type' => 'info',
									'desc' => esc_html__( 'You can control Social Share buttons from "Social Buttons" tab present in the options panel.', 'dropshipping' ),
								],
							],
						],
						'previous-next' => [
							'label'     => esc_html__( 'Previous & Next Posts', 'dropshipping' ),
							'subfields' => [],
						],
						'related'       => [
							'label'     => esc_html__( 'Related Posts', 'dropshipping' ),
							'subfields'	=> [
								[
									'id'       => 'mts_related_posts_taxonomy',
									'type'     => 'button_set',
									'title'    => esc_html__( 'Related Posts Taxonomy', 'dropshipping' ),
									'options'  => [
										'tags'       => esc_html__( 'Tags', 'dropshipping' ),
										'categories' => esc_html__( 'Categories', 'dropshipping' ),
									],
									'class' => 'green',
									'sub_desc' => esc_html__( 'Related Posts based on tags or categories.', 'dropshipping' ),
									'std'      => 'categories',
								],
								[
									'id'       => 'mts_related_postsnum',
									'type'     => 'text',
									'class'    => 'small-text',
									'title'    => esc_html__( 'Number of related posts', 'dropshipping' ),
									'sub_desc' => esc_html__( 'Enter the number of posts to show in the related posts section.', 'dropshipping' ),
									'std'      => '6',
									'args'     => [ 'type' => 'number' ],
								],
							],
						],
					],
					'disabled' => [],
				],
			],
			[
				'id'       => 'mts_single_meta_info_enable',
				'type'     => 'multi_checkbox',
				'title'    => esc_html__( 'Single Post Meta Info', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on the single post', 'dropshipping' ),
				'options'  => [
					'category' => esc_html__( 'Enable Category', 'dropshipping' ),
					'author'   => esc_html__( 'Enable Author Name', 'dropshipping' ),
					'comment'  => esc_html__( 'Enable Comments', 'dropshipping' ),
					'time'     => esc_html__( 'Enable Time/Date', 'dropshipping' ),
				],
				'std'      => [
					'category' => '1',
					'author'   => '1',
					'comment'  => '1',
					'time'     => '1',
				],
			],
			[
				'id'       => 'mts_single_featured_image',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Show Featured Image', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Use this button to show Featured Image on Single Post', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'std'      => '1',
			],
			[
				'id'       => 'mts_breadcrumb',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Breadcrumbs', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_author_comment',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Highlight Author Comment', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to highlight author comments.', 'dropshipping' ),
				'std'      => '1',
			],
			[
				'id'       => 'mts_comment_date',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Date in Comments', 'dropshipping' ),
				'options'  => [
					'0' => esc_html__( 'Off', 'dropshipping' ),
					'1' => esc_html__( 'On', 'dropshipping' ),
				],
				'sub_desc' => esc_html__( 'Use this button to show the date for comments.', 'dropshipping' ),
				'std'      => '1',
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-group',
		'title'  => esc_html__( 'Social Buttons', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Enable or disable social sharing buttons on single posts using these buttons.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_social_buttons',
				'type'     => 'layout',
				'title'    => esc_html__( 'Social Media Buttons', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Organize how you want the social sharing buttons to appear on single posts', 'dropshipping' ),
				'options'  => [
					'enabled'  => [
						'facebookshare' => esc_html__( 'Facebook Share', 'dropshipping' ),
						'twitter'       => esc_html__( 'Twitter', 'dropshipping' ),
						'linkedin'      => esc_html__( 'LinkedIn', 'dropshipping' ),
						'pinterest'     => esc_html__( 'Pinterest', 'dropshipping' ),
						'telegram'      => esc_html__( 'Telegram', 'dropshipping' ),
					],
					'disabled' => [
						'buffer'    => esc_html__( 'Buffer', 'dropshipping' ),
						'mix'       => esc_html__( 'Mix', 'dropshipping' ),
						'tumblr'    => esc_html__( 'Tumblr', 'dropshipping' ),
						'pocket'    => esc_html__( 'Pocket', 'dropshipping' ),
						'vkontakte' => esc_html__( 'Vkontakte', 'dropshipping' ),
						'reddit'    => esc_html__( 'Reddit', 'dropshipping' ),
						'whatsapp'  => esc_html__( 'WhatsApp', 'dropshipping' ),
					],
				],
				'std'  => [
					'enabled'  => [
						'facebookshare' => esc_html__( 'Facebook Share', 'dropshipping' ),
						'twitter'       => esc_html__( 'Twitter', 'dropshipping' ),
						'linkedin'      => esc_html__( 'LinkedIn', 'dropshipping' ),
						'pinterest'     => esc_html__( 'Pinterest', 'dropshipping' ),
						'telegram'      => esc_html__( 'Telegram', 'dropshipping' ),
					],
					'disabled' => [
						'buffer'    => esc_html__( 'Buffer', 'dropshipping' ),
						'mix'       => esc_html__( 'Mix', 'dropshipping' ),
						'tumblr'    => esc_html__( 'Tumblr', 'dropshipping' ),
						'pocket'    => esc_html__( 'Pocket', 'dropshipping' ),
						'vkontakte' => esc_html__( 'Vkontakte', 'dropshipping' ),
						'reddit'    => esc_html__( 'Reddit', 'dropshipping' ),
						'whatsapp'  => esc_html__( 'WhatsApp', 'dropshipping' ),
					],
				],
			],
			[
				'id'       => 'mts_product_social_buttons',
				'type'     => 'layout',
				'title'    => esc_html__( 'Product Social Media Buttons', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Organize how you want the social sharing buttons to appear on single product', 'dropshipping' ),
				'options'  => [
					'enabled'  => [
						'facebookshare' => esc_html__( 'Facebook Share', 'dropshipping' ),
						'twitter'       => esc_html__( 'Twitter', 'dropshipping' ),
						'linkedin'      => esc_html__( 'LinkedIn', 'dropshipping' ),
						'pinterest'     => esc_html__( 'Pinterest', 'dropshipping' ),
						'telegram'      => esc_html__( 'Telegram', 'dropshipping' ),
					],
					'disabled' => [
						'buffer'    => esc_html__( 'Buffer', 'dropshipping' ),
						'mix'       => esc_html__( 'Mix', 'dropshipping' ),
						'tumblr'    => esc_html__( 'Tumblr', 'dropshipping' ),
						'pocket'    => esc_html__( 'Pocket', 'dropshipping' ),
						'vkontakte' => esc_html__( 'Vkontakte', 'dropshipping' ),
						'reddit'    => esc_html__( 'Reddit', 'dropshipping' ),
						'whatsapp'  => esc_html__( 'WhatsApp', 'dropshipping' ),
					],
				],
				'std'  => [
					'enabled'  => [
						'facebookshare' => esc_html__( 'Facebook Share', 'dropshipping' ),
						'twitter'       => esc_html__( 'Twitter', 'dropshipping' ),
						'linkedin'      => esc_html__( 'LinkedIn', 'dropshipping' ),
						'pinterest'     => esc_html__( 'Pinterest', 'dropshipping' ),
						'telegram'      => esc_html__( 'Telegram', 'dropshipping' ),
					],
					'disabled' => [
						'buffer'    => esc_html__( 'Buffer', 'dropshipping' ),
						'mix'       => esc_html__( 'Mix', 'dropshipping' ),
						'tumblr'    => esc_html__( 'Tumblr', 'dropshipping' ),
						'pocket'    => esc_html__( 'Pocket', 'dropshipping' ),
						'vkontakte' => esc_html__( 'Vkontakte', 'dropshipping' ),
						'reddit'    => esc_html__( 'Reddit', 'dropshipping' ),
						'whatsapp'  => esc_html__( 'WhatsApp', 'dropshipping' ),
					],
				],
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-bar-chart-o',
		'title'  => esc_html__( 'Ad Management', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'dropshipping' ) . '</p>',
		'fields' => [
			[
				'id'       => 'mts_posttop_adcode',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Below Post Title', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', 'dropshipping' )
			],
			[
				'id'       => 'mts_posttop_adcode_time',
				'type'     => 'text',
				'title'    => esc_html__( 'Show After X Days', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'dropshipping' ),
				'validate' => 'numeric',
				'std'      => '0',
				'class'    => 'small-text',
				'args'     => [ 'type' => 'number' ],
			],
			[
				'id'       => 'mts_postend_adcode',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Below Post Content', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', 'dropshipping' )
			],
			[
				'id'       => 'mts_postend_adcode_time',
				'type'     => 'text',
				'title'    => esc_html__( 'Show After X Days', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'dropshipping' ),
				'validate' => 'numeric',
				'std'      => '0',
				'class'    => 'small-text',
				'args'     => [ 'type' => 'number' ],
			],
		],
	];

	$sections[] = [
		'icon'   => 'fa fa-columns',
		'title'  => esc_html__( 'Sidebars', 'dropshipping' ),
		'desc'   => '<p class="description">' . esc_html__( 'Now you have full control over the sidebars. Here you can manage sidebars and select one for each section of your site, or select a custom sidebar on a per-post basis in the post editor.', 'dropshipping' ) . '<br></p>',
		'fields' => [
			[
				'id'        => 'mts_custom_sidebars',
				'type'      => 'group', // doesn't need to be called for callback fields.
				'title'     => esc_html__( 'Custom Sidebars', 'dropshipping' ),
				'sub_desc'  => wp_kses( __( 'Add custom sidebars. <strong style="font-weight: 800;">You need to save the changes to use the sidebars in the dropdowns below.</strong><br />You can add content to the sidebars in Appearance &gt; Widgets.', 'dropshipping' ), [ 'strong' => '', 'br' => '' ] ),
				'groupname' => esc_html__( 'Sidebar', 'dropshipping' ), // Group name.
				'subfields' => [
					[
						'id'       => 'mts_custom_sidebar_name',
						'type'     => 'text',
						'title'    => esc_html__( 'Name', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Example: Homepage Sidebar', 'dropshipping' )
					],
					[
						'id'       => 'mts_custom_sidebar_id',
						'type'     => 'text',
						'title'    => esc_html__( 'ID', 'dropshipping' ),
						'sub_desc' => esc_html__( 'Enter a unique ID for the sidebar. Use only alphanumeric characters, underscores (_) and dashes (-), eg. "sidebar-home"', 'dropshipping' ),
						'std'      => 'sidebar-',
					],
				],
			],
			[
				'id'       => 'mts_sidebar_for_home',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Homepage', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the homepage.', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_post',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Single Post', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the single posts. If a post has a custom sidebar set, it will override this.', 'dropshipping' ),
				'args'     => [ 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_page',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Single Page', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the single pages. If a page has a custom sidebar set, it will override this.', 'dropshipping' ),
				'args'     => [ 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_archive',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Archive', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the archives. Specific archive sidebars will override this setting (see below).', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_category',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Category Archive', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the category archives.', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_tag',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Tag Archive', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the tag archives.', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_date',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Date Archive', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the date archives.', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_author',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Author Archive', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the author archives.', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_search',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Search', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the search results.', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_notfound',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( '404 Error', 'dropshipping' ),
				'sub_desc' => esc_html__( 'Select a sidebar for the 404 Not found pages.', 'dropshipping' ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => '',
			],
			[
				'id'       => 'mts_sidebar_for_shop',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Shop Pages', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Select a sidebar for Shop main page and product archive pages (WooCommerce plugin must be enabled). Default is <strong>Shop Page Sidebar</strong>.', 'dropshipping' ), [ 'strong' => '' ] ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => 'shop-sidebar',
			],
			[
				'id'       => 'mts_sidebar_for_product',
				'type'     => 'sidebars_select',
				'title'    => esc_html__( 'Single Product', 'dropshipping' ),
				'sub_desc' => wp_kses( __( 'Select a sidebar for single products (WooCommerce plugin must be enabled). Default is <strong>Single Product Sidebar</strong>.', 'dropshipping' ), [ 'strong' => '' ] ),
				'args'     => [ 'allow_nosidebar' => false, 'exclude' => $exclude_sidebars ],
				'std'      => 'product-sidebar',
			],
		],
	];

	$sections[] = [
		'icon'  => 'fa fa-list-alt',
		'title' => esc_html__( 'Navigation', 'dropshipping' ),
		'desc'  => '<p class="description"><div class="controls">' . sprintf( esc_html__( 'Navigation settings can now be modified from the %s.', 'dropshipping' ), '<a href="nav-menus.php"><b>' . __( 'Menus Section', 'dropshipping' ) . '</b></a>' ) . '<br></div></p>'
	];

	$tabs = [];

	$args['presets'] = [];
	$args['show_translate'] = false;
	include( 'theme-presets.php' );

	global $NHP_Options;
	$NHP_Options = new NHP_Options( $sections, $args, $tabs );

}

add_action( 'init', 'setup_framework_options', 0 );

/*
 *
 * Custom function for the callback referenced above
 *
 */
function my_custom_field( $field, $value ) {
	print_r( $field );
	print_r( $value );

}

/*
 *
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function( $field, $value, $existing_value ) {

	$error = false;
	$value = 'just testing';
	$return['value'] = $value;
	if( $error == true ) {
		$return['error'] = $field;
	}
	return $return;

}

/*--------------------------------------------------------------------
 *
 * Default Font Settings
 *
 --------------------------------------------------------------------*/
if ( function_exists( 'mts_register_typography' ) ) {
	mts_register_typography(
		[
			'logo_font'                 => [
				'preview_text'  => esc_html__( 'Logo Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => '700',
				'font_size'     => '40px',
				'font_color'    => '#000000',
				'css_selectors' => '#logo a',
			],
			'navigation_font'           => [
				'preview_text'   => esc_html__( 'Top Header Font', 'dropshipping' ),
				'preview_color'  => 'dark',
				'font_family'    => 'Lato',
				'font_variant'   => 'normal',
				'font_size'      => '12px',
				'font_color'     => '#ffffff',
				'additional_css' => 'text-transform: uppercase;',
				'css_selectors'  => '.top-description, .top-header .navigation',
			],
			'primary_navigation_font'   => [
				'preview_text'  => esc_html__( 'Primary Nav Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => '700',
				'font_size'     => '14px',
				'font_color'    => '#494949',
				'css_selectors' => '#primary-navigation a',
			],
			'secondary_navigation_font' => [
				'preview_text'   => esc_html__( 'Secondary Nav Font', 'dropshipping' ),
				'preview_color'  => 'dark',
				'font_family'    => 'Lato',
				'font_variant'   => '700',
				'font_size'      => '13px',
				'font_color'     => '#333333',
				'additional_css' => 'text-transform: uppercase;',
				'css_selectors'  => '#secondary-navigation a, .header-button',
			],
			'featured_slider_font'      => [
				'preview_text'  => esc_html__( 'Featured Slider Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '52px',
				'font_color'    => '#333333',
				'css_selectors' => '.primary-slider .slide-caption',
			],
			'featured_categories_font'  => [
				'preview_text'  => esc_html__( 'Featured Categories Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '14px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.featured-categories-products',
			],
			'featured_tabs_font'        => [
				'preview_text'  => esc_html__( 'Featured Tabs Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '14px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.featured-product-tabs',
			],
			'product_slider_font'       => [
				'preview_text'  => esc_html__( 'Product Slider Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '54px',
				'font_color'    => '#ffffff',
				'css_selectors' => '.product-slider .slide-caption',
			],
			'call_to_action_font'       => [
				'preview_text'  => esc_html__( 'Call To Action Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '14px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.call-to-action',
			],
			'newsletter_font'           => [
				'preview_text'  => esc_html__( 'Newsletter Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '14px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.mts-dropshipping-newsletter .widget .wp-subscribe',
			],
			'home_blog_font'            => [
				'preview_text'  => esc_html__( 'Blog Section Font', 'dropshipping' ),
				'preview_color' => 'dark',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '14px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.homepage-blog-section',
			],
			'home_title_font'           => [
				'preview_text'  => esc_html__( 'Home Article Title', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_size'     => '24px',
				'font_variant'  => '600',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.latestPost .title',
			],
			'post_info_font'            => [
				'preview_text'  => esc_html__( 'Post Info text', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Lato',
				'font_size'     => '14px',
				'font_variant'  => 'normal',
				'font_color'    => '#a4a4a4',
				'css_selectors' => '.post-info, .pagination',
			],
			'footer_carousel_font'      => [
				'preview_text'  => esc_html__( 'Footer Carousel Font', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Lato',
				'font_size'     => '14px',
				'font_variant'  => 'normal',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.footer-carousel-section',
			],
			'page_title_font'           => [
				'preview_text'  => esc_html__( 'Page Title Font', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_size'     => '68px',
				'font_variant'  => '600',
				'font_color'    => '#ffffff',
				'css_selectors' => '.page-title .title, .single-post .breadcrumb, .archive .breadcrumb',
			],
			'shop_title_font'           => [
				'preview_text'  => esc_html__( 'Shop Title Font', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_size'     => '68px',
				'font_variant'  => '600',
				'font_color'    => '#ffffff',
				'css_selectors' => '.shop-title .title, .shop-product-categories, .shop-single-background .title, .shop-single-background .woocommerce-breadcrumb',
			],
			'checkout_progress_font'    => [
				'preview_text'   => esc_html__( 'Checkout Progress Font', 'dropshipping' ),
				'preview_color'  => 'light',
				'font_family'    => 'Poppins',
				'font_size'      => '22px',
				'font_variant'   => '600',
				'font_color'     => '#ffffff',
				'additional_css' => 'text-transform: uppercase;',
				'css_selectors'  => '.mts-checkout-item',
			],
			'single_title_font'         => [
				'preview_text'  => esc_html__( 'Single Article Title', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_size'     => '32px',
				'font_variant'  => '600',
				'font_color'    => '#2d2a2a',
				'css_selectors' => '.single-title',
			],
			'content_font'              => [
				'preview_text'  => esc_html__( 'Content Font', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Lato',
				'font_size'     => '14px',
				'font_variant'  => 'normal',
				'font_color'    => '#777777',
				'css_selectors' => 'body',
			],
			'sidebar_title'             => [
				'preview_text'   => esc_html__( 'Sidebar Title', 'dropshipping' ),
				'preview_color'  => 'light',
				'font_family'    => 'Poppins',
				'font_variant'   => '600',
				'font_size'      => '16px',
				'font_color'     => '#2d2a2a',
				'additional_css' => 'text-transform: uppercase;',
				'css_selectors'  => '.widget h3',
			],
			'sidebar_heading'           => [
				'preview_text'  => esc_html__( 'Sidebar Post Heading', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '500',
				'font_size'     => '14px',
				'font_color'    => '#333333',
				'css_selectors' => '.widget .post-title, .sidebar .widget .entry-title, .widget .slide-title, .widget .wpt_comment_meta',
			],
			'sidebar_font'              => [
				'preview_text'  => esc_html__( 'Sidebar Font', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '14px',
				'font_color'    => '#777777',
				'css_selectors' => '.widget',
			],
			'footer_heading'            => [
				'preview_text'   => esc_html__( 'Footer Heading', 'dropshipping' ),
				'preview_color'  => 'light',
				'font_family'    => 'Poppins',
				'font_variant'   => '600',
				'font_size'      => '16px',
				'font_color'     => '#2d2a2a',
				'additional_css' => 'text-transform: uppercase;',
				'css_selectors'  => '#site-footer .widget h3',
			],
			'footer_title_font'         => [
				'preview_text'  => esc_html__( 'Footer Post Heading', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '500',
				'font_size'     => '14px',
				'font_color'    => '#333333',
				'css_selectors' => '#site-footer .widget .post-title, #site-footer .widget .entry-title, #site-footer .widget .slide-title, #site-footer .widget .wpt_comment_meta',
			],
			'footer_font'               => [
				'preview_text'  => esc_html__( 'Footer Font', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Lato',
				'font_variant'  => 'normal',
				'font_size'     => '14px',
				'font_color'    => '#777777',
				'css_selectors' => '#site-footer .widget, #site-footer',
			],
			'h1_headline'               => [
				'preview_text'  => esc_html__( 'Content H1', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '600',
				'font_size'     => '28px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => 'h1',
			],
			'h2_headline'               => [
				'preview_text'  => esc_html__( 'Content H2', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '600',
				'font_size'     => '24px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => 'h2',
			],
			'h3_headline'               => [
				'preview_text'  => esc_html__( 'Content H3', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '600',
				'font_size'     => '22px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => 'h3',
			],
			'h4_headline'               => [
				'preview_text'  => esc_html__( 'Content H4', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '600',
				'font_size'     => '20px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => 'h4',
			],
			'h5_headline'               => [
				'preview_text'  => esc_html__( 'Content H5', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '600',
				'font_size'     => '18px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => 'h5',
			],
			'h6_headline'               => [
				'preview_text'  => esc_html__( 'Content H6', 'dropshipping' ),
				'preview_color' => 'light',
				'font_family'   => 'Poppins',
				'font_variant'  => '600',
				'font_size'     => '16px',
				'font_color'    => '#2d2a2a',
				'css_selectors' => 'h6, .woocommerce .comment-reply-title, td.product-name a, table th, .woocommerce div.product .woocommerce-tabs ul.tabs',
			],
		]
	);
}
