<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.4.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $mts_options;

get_header( 'shop' ); ?>

<div class="shop-background shop-title">

	<div class="container">

	<?php if ( is_shop() ) { ?>
		<h1 class="title"><?php esc_html_e( 'Shop', 'dropshipping' ); ?></h1>
		<?php } else { ?>	
			<h1 class="title"><?php woocommerce_page_title(); ?></h1>	
			<?php } ?>

		<?php
		if ( ! empty( $mts_options['mts_shop_product_categories'] ) || is_product_taxonomy() ) {
			?>

		<div class="shop-product-categories">
			<?php
			foreach ( $mts_options['mts_shop_product_categories'] as $product ) {
				$product_count       = '';
				$product_category_id = $product['mts_shop_product_category'];
				$product_cat         = get_term_by( 'id', $product_category_id, 'product_cat' );
				// Products arguments.
				$args = [
					'post_type' => 'product',
					'tax_query' => [
						[
							'taxonomy' => 'product_cat',
							'field'    => 'id',
							'terms'    => $product_category_id,
						],
					],
				];
				// count queries.
				$the_query = new WP_Query( $args );
				if ( $the_query->have_posts() ) {
					$product_count = $the_query->found_posts;
				}
				?>
				<div class="mts-category-nav">
					<a class="mts-category-nav-link" href="<?php echo esc_url( get_term_link( $product_cat->slug, 'product_cat' ) ); ?>">
						<div class="category-icon fa fa-<?php print esc_attr( $product['mts_shop_product_icon'] ); ?>"></div>
						<div class="mts-category-summary">
							<div class="category-name"><?php echo esc_attr( $product_cat->name ); ?></div>
							<div class="category-count">
							<?php
							if ( 0 === $product_count || 1 === $product_count ) {
								echo $product_count . '&nbsp;' . esc_html__( 'Product', 'dropshipping' );
							}
							if ( 1 < $product_count ) {
								echo $product_count . '&nbsp;' . esc_html__( 'Products', 'dropshipping' );
							}
							?>
							</div>				
						</div>							
					</a>
				</div>
				<?php
			}
			?>
		</div>
		<?php } ?>
		</div>
</div>
<div id="page">
	<article class="<?php mts_article_class(); ?>">
		<div id="content_box" >
			<?php
				/**
				 * Woocommerce_before_main_content hook
				 *
				 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
				 * @hooked woocommerce_breadcrumb - 20
				 */
				do_action( 'woocommerce_before_main_content' );
			?>
				<?php woocommerce_catalog_ordering(); ?>
				<?php do_action( 'woocommerce_archive_description' ); ?>

			<?php if ( have_posts() ) : ?>

				<?php
					/**
					 * Woocommerce_before_shop_loop hook
					 *
					 * @hooked woocommerce_result_count - 20
					 * @hooked woocommerce_catalog_ordering - 30
					 */
					do_action( 'woocommerce_before_shop_loop' );
				?>

				<?php woocommerce_product_loop_start(); ?>

					<div class="mts-product-categories"><?php woocommerce_product_subcategories(); ?></div>

					<div class="mts-shop-products">
						<?php while ( have_posts() ) : the_post(); ?>
								<?php wc_get_template_part( 'content', 'product' ); ?>
						<?php endwhile; // end of the loop. ?>
					</div>

				<?php woocommerce_product_loop_end(); ?>

				<?php
					/**
					 * Hook: woocommerce_after_shop_loop.
					 *
					 * @hooked woocommerce_pagination - 10
					 */
					do_action( 'woocommerce_after_shop_loop' );
				?>

			<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

				<?php wc_get_template( 'loop/no-products-found.php' ); ?>

			<?php endif; ?>

		<?php
			/**
			 * Hook: woocommerce_after_main_content.
			 *
			 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
			 */
			do_action( 'woocommerce_after_main_content' );
		?>
		</div>
	</article>
	<?php
	/**
	 * Hook: woocommerce_sidebar.
	 *
	 * @hooked woocommerce_get_sidebar - 10
	 */
	?>
	<?php get_sidebar(); ?>
<?php get_footer( 'shop' ); ?>
